/*****************************************************************

  Code of MAIDEN model (Modelling and Analysis In DENdroecology)

    Developed by Laurent Misson.
    First version Maiden1.0, finished in June 2002. Complete description in:

	Misson L. (2004). MAIDEN: a model to analyze ecosystem processes in dendroecology.
	Canadian Journal of Forest Research 34: 874-887.

	Misson L, Rathgeber C, Guiot J. (2004). Dendroecological analysis of climatic effects on Quercus petraea
	and Pinus halepensis radial growth using the process-based MAIDEN model.
	Canadian Journal of Forest Research 34: 888-898.

    Current developers and contacts
    Guillermo Gea-Izquierdo
    Fabio Gennaretti
    Etienne Boucher
    Ignacio Hermoso de Mendoza
    Alienor Lavergne
*/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <time.h>
#include <math.h>
//#include <io.h>
#include <float.h>
//#include <dos.h>
//#include <direct.h>
//#include <malloc.h>
#include <iostream> // -Wno-deprecated dans Makefile
#include <fstream>
#include <time.h>

#include "Constants.h"
#include "Maiden_struct.h"
#include "Maiden_funct.h"

int nslay;
int ndays;
int year0;
int model_version;
int exp_site;

/********************************
**                             **
**    FILE DECLARATION         **
**                             **
********************************/

FILE *inmet;			// meteorological input
FILE *inpar;			// parameters
FILE *exportflags;          // system state input

FILE *outmet;			// meteorological output
FILE *outd18O_day;			// isotopes parameters outputs PAD 281008
FILE *outd18O_year;            // isotopes parameters outputs PAD 281008
FILE *outd2H;			//
FILE *outd13C_day;			//
FILE *outd13C_year;            //
FILE *outsoil;			// soil output
FILE *outsnow;			// snow output
FILE *outtemp;			// temperature output
FILE *outroot;
FILE *outwater;
FILE *outphoto;
FILE *outalloc_year;
FILE *outalloc_day;
FILE *outtrans;
FILE *outwatbalance;
FILE *outsim;
FILE *outrad;
FILE *outphenol;
FILE *outsoilev;
FILE *outcalib;
FILE *outcustom;

/********************************
**                             **
**      START OF MAIN()        **
**                             **
********************************/
int main(void) // PAD 241008 void main()
{
	/* variable declarations */
	int i;

	/* structured variables declaration */
	phenol_struct phenol;
	param_struct par;
	site_struct site;	    /* parameters */
	meteo_struct meteo;         /* meteorological data arrays */
	soil_struct soil;
	photo_struct photo;
	radiation_struct rad;
	allocation_struct alloc;
	water_struct water;
	water_an_struct water_an;
	soilev_struct soilev;
	d18O_struct d18O;
	d2H_struct d2H;
	d13C_struct d13C;

	/* meteorological output and input */
	inmet = fopen("inmet.txt","r");

	/* read input parameter file */
	read_init(&site,&par);
	printf("read_init OK\n");

	/* allocate space in the data arrays for input and output data */
	data_alloc(&soilev, &meteo, &water, &rad, &photo, &alloc, &soil, &water_an, &phenol, &d18O, &d2H, &d13C, &par);

	i=0;

	/* read meteorological data from input file into data arrays */
	read_inmet(&meteo,&water,&par,&d18O,&d2H,&d13C);
	printf("read_inmet OK\n");

	/* estimate daily air temperatures */
	calc_tair(&site,&par,&meteo,&phenol);
	printf("calc_tair OK\n");

	/* estimate daily precipitation */
	calc_prcp(&site,&par,&meteo);
	printf("calc_prcp OK\n");

	/* estimate daily d18O and d2H in precipitation and in vapor*/
	calc_d18O2H_PV(&site,&par,&meteo,&d18O,&d2H); // in meteorology
	printf("calc_d18O2H_PV OK\n");

	/* estimate daily snowpack */
	snowpack(&site,&par,&meteo);
	printf("snowpack OK\n");

	/* no dewpoint temperature data */
	/* estimate srad and humidity with iterative algorithm */
	/* with change meteo->s_prcp from cm to mm PAD 280509 */
	calc_srad_humidity_iterative(&site,&par,&meteo,&rad);
	printf("calc_srad_humidity_iterative OK\n");

	printf("ndays=%d\n",ndays);
 	for (i=0 ; i<ndays ; i++)
	  {
	    //printf("Num of simulated days : %i\n",i);
	    radtrans(&par,&meteo,&rad,&alloc,i);
	    //printf("radtrans OK\n");

	    // throughfall(&par,&meteo,&water,&rad,&alloc,i);
	    throughfall_iso(&par,&meteo,&water,&rad,&alloc,&d18O,&d2H,i);//PAD 211108
	    //printf("throughfall_iso OK\n");

	    soil_evap(&par,&soilev,&meteo,&water,&soil,&rad,i);
	    //printf("soil_evap OK\n");

        photosynthesis(&par,&meteo,&photo,&soil,&rad,&water,&alloc,&phenol,i);
	    //printf("photosynthesis OK\n");

	    transpiration(&par,&meteo,&water,&photo,&rad,i);
	    //printf("transpiration OK\n");

	    soih2o_iso(&site,&par,&meteo,&water_an,&soil,&water,&d18O,&d2H,i,&alloc,&soilev);
	    //printf("soih2o_iso OK (Maiden)\n");

	    TRC_iso(&meteo,&d18O,&d2H,&photo,&d13C,&alloc,i,&par); // PAD 141108
	    //printf("TRC_iso OK (Maiden)\n");

	    phenology(&phenol,&meteo,&photo,&water,&par,i);
	    //printf("phenology OK\n");

	    allocation(&par,&phenol,&soil,&water,&meteo,&photo,&alloc,&rad,i);
	    //printf("allocation OK\n");

	    root(&par, &soil, &alloc, &water, i); // PAD 201108
	    //printf("root OK\n");

	  } /* end for i = ndays loop */

	printf("FIN BOUCLE (i=%d)\n",i);

	/* write output file */
	write_out(&meteo,&soil,&water,&rad,&photo,&alloc,&water_an,&phenol,&soilev,
		  &d18O,&d2H,&d13C,&par);

	/* create a backup in a subdirectory for all the files in the project */
	//backup(); enlev car realiser dans reglage.py PAD 271008

	/* free previously allocated memory before returning */
	///data_free(&meteo,&soil,&water,&rad,&photo,&alloc,&water_an,&phenol,&d18O,&d2H,&d13C); //FG_ERROR
	// ATTENTION, ne marche pas encore sur Idefix PAD 311008

	return 0;
			/* This statement serves no purpose except  */
			/* to coddle misguided and narrow-minded    */
			/* specifications made by an ANSI committee */
			/* which didn't realize that I might write  */
			/* a main() which never returns.            */

}
/* end of main */

/*******************************************/
/* read_init() reads data out of init file */
/*******************************************/
int read_init(site_struct *site, param_struct *par)
{
    //char var; FG
	int ok=1;

	//Parameters file
	inpar = fopen( "inpar2.txt" , "r");
	//1. verify inpar + inmet + meteosite
	//2. verify outsim + coefficient + years
	//3. verify fitted parameters

    if(inpar == 0) {
        perror("fopen");
        exit(1);
    }

    /// Environment variables
    fscanf(inpar,"%i%*[^\n]",&par->model_version);
        model_version = par->model_version; // 1: Mediterranean ; 2 : Picea Mariana

	/// Site variables
    fscanf(inpar,"%i%*[^\n]",&par->exp_site);
        exp_site = par->exp_site; // 1: Deciduous ; 2: Evergreen
    fscanf(inpar,"%i%*[^\n]",&par->nslay);
        nslay = par->nslay;
    fscanf(inpar,"%lf%*[^\n]",&par->base_elev);
    fscanf(inpar,"%lf%*[^\n]",&par->base_isoh);
    fscanf(inpar,"%lf%*[^\n]",&par->site_lat);
    fscanf(inpar,"%lf%*[^\n]",&par->site_elev);
    fscanf(inpar,"%lf%*[^\n]",&par->site_slp);
    fscanf(inpar,"%lf%*[^\n]",&par->site_asp);
    fscanf(inpar,"%lf%*[^\n]",&par->site_isoh);
    fscanf(inpar,"%lf%*[^\n]",&par->site_ehoriz);
    fscanf(inpar,"%lf%*[^\n]",&par->site_whoriz);
    fscanf(inpar,"%lf%*[^\n]",&par->tmax_lr);
    fscanf(inpar,"%lf%*[^\n]",&par->tmin_lr);
    fscanf(inpar,"%lf%*[^\n]",&site->site_chf);
    fscanf(inpar,"%i%*[^\n]",&par->ndays);
        ndays = par->ndays;
    fscanf(inpar,"%i%*[^\n]",&par->year0);
        year0 = par->year0;
    fscanf(inpar,"%i%*[^\n]",&par->yearn);
    fscanf(inpar,"%i%*[^\n]",&par->year0_sim);
    fscanf(inpar,"%i%*[^\n]",&par->yearn_sim);

	///Meteorology
	fscanf(inpar,"%lf%*[^\n]",&par->ws_cst);
	fscanf(inpar,"%i%*[^\n]",&par->CO2_flag); // PAD 291008

	///Radiation
	fscanf(inpar,"%lf%*[^\n]",&par->WAI);
	fscanf(inpar,"%lf%*[^\n]",&par->LAImax);
	fscanf(inpar,"%lf%*[^\n]",&par->k);
	fscanf(inpar,"%lf%*[^\n]",&par->lai_par);
    fscanf(inpar,"%lf%*[^\n]",&par->abs_compet_k); // FG // GGI radiation

	/// Throughfall
	fscanf(inpar,"%lf%*[^\n]",&par->clumping);
	fscanf(inpar,"%lf%*[^\n]",&par->cws_max);
	fscanf(inpar,"%lf%*[^\n]",&par->css_max);

	/// Soil
	fscanf(inpar,"%lf%*[^\n]",&par->soil_stress);
	fscanf(inpar,"%lf%*[^\n]",&par->soilwmin);
	fscanf(inpar,"%lf%*[^\n]",&par->sat);
//	fscanf(inpar,"%lf%*[^\n]",&par->infil);
    fscanf(inpar,"%lf%*[^\n]",&par->thaw_thres);

	fscanf(inpar,"%lf%*[^\n]",&par->thick1);
	fscanf(inpar,"%lf%*[^\n]",&par->thick2);
	fscanf(inpar,"%lf%*[^\n]",&par->thick3);
	fscanf(inpar,"%lf%*[^\n]",&par->thick4);
	fscanf(inpar,"%lf%*[^\n]",&par->thick5); // PAD 260209

	fscanf(inpar,"%lf%*[^\n]",&par->finefrac1);
	fscanf(inpar,"%lf%*[^\n]",&par->finefrac2);
	fscanf(inpar,"%lf%*[^\n]",&par->finefrac3);
	fscanf(inpar,"%lf%*[^\n]",&par->finefrac4);
	fscanf(inpar,"%lf%*[^\n]",&par->finefrac5); // PAD 260209

	fscanf(inpar,"%lf%*[^\n]",&par->clay1);
	fscanf(inpar,"%lf%*[^\n]",&par->clay2);
	fscanf(inpar,"%lf%*[^\n]",&par->clay3);
	fscanf(inpar,"%lf%*[^\n]",&par->clay4);
	fscanf(inpar,"%lf%*[^\n]",&par->clay5); // PAD 260209

	fscanf(inpar,"%lf%*[^\n]",&par->sand1);
	fscanf(inpar,"%lf%*[^\n]",&par->sand2);
	fscanf(inpar,"%lf%*[^\n]",&par->sand3);
	fscanf(inpar,"%lf%*[^\n]",&par->sand4);
	fscanf(inpar,"%lf%*[^\n]",&par->sand5); // PAD 260209

    fscanf(inpar,"%lf%*[^\n]",&par->swp_wp);
    fscanf(inpar,"%lf%*[^\n]",&par->b_soil); // FG // GGI soil water

	/// Photosynthesis
	fscanf(inpar,"%lf%*[^\n]",&par->leuning_a);
	fscanf(inpar,"%lf%*[^\n]",&par->VPD0);
	fscanf(inpar,"%lf%*[^\n]",&par->Vcmax);
	fscanf(inpar,"%lf%*[^\n]",&par->JmaxCoef);
	fscanf(inpar,"%lf%*[^\n]",&par->RdayCoef);
    fscanf(inpar,"%lf%*[^\n]",&par->b); // FG // GGI photosintesis
    fscanf(inpar,"%lf%*[^\n]",&par->Ts); // FG // GGI photosintesis
    fscanf(inpar,"%lf%*[^\n]",&par->perc_vcmax); // FG // GGI photosintesis
    fscanf(inpar,"%lf%*[^\n]",&par->theta_inpar); // FG
    fscanf(inpar,"%lf%*[^\n]",&par->s_tday_tau); // FG
    fscanf(inpar,"%lf%*[^\n]",&par->Photo_Temp_T1); // Temperature threshold for photosynthesis equal 0 g m-2
    fscanf(inpar,"%lf%*[^\n]",&par->Photo_Temp_T2); // Temperature threshold for photosynthesis equal 0.1 g m-2

    /// Isotopes
	fscanf(inpar,"%i%*[^\n]",&par->d18O_flag); // PAD 291008
	fscanf(inpar,"%lf%*[^\n]",&par->ff_d18O);
    fscanf(inpar,"%lf%*[^\n]",&par->Eps_bio);
    fscanf(inpar,"%lf%*[^\n]",&par->ff_d13C);
    fscanf(inpar,"%lf%*[^\n]",&par->Dst_dest);
    fscanf(inpar,"%lf%*[^\n]",&par->Dc_p); // FG
    fscanf(inpar,"%lf%*[^\n]",&par->a_rain); // FG Estimation of D18O of the rain - Temperature dependence
    fscanf(inpar,"%lf%*[^\n]",&par->b_rain); // FG Estimation of D18O of the rain - Precipitation dependence
    fscanf(inpar,"%lf%*[^\n]",&par->c_rain); // FG Estimation of D18O of the rain - Intercept
    fscanf(inpar,"%lf%*[^\n]",&par->a_snow); // FG Estimation of D18O of the rain - Temperature dependence
    fscanf(inpar,"%lf%*[^\n]",&par->b_snow); // FG Estimation of D18O of the rain - Precipitation dependence
    fscanf(inpar,"%lf%*[^\n]",&par->c_snow); // FG Estimation of D18O of the rain - Intercept
    fscanf(inpar,"%lf%*[^\n]",&par->Eps_Kin); // FG Eps_Kin in Anderson's function, parameter to estimate the fractionation as water diffuses through the stomata and the leaf boundary layer
    fscanf(inpar,"%lf%*[^\n]",&par->rad_trans); // Resistance to evaporative vapour transfer
    fscanf(inpar,"%lf%*[^\n]",&par->snowblow); // Fraction of snowfall that blows

	///Phenology
	fscanf(inpar,"%lf%*[^\n]",&par->gdd);
	fscanf(inpar,"%lf%*[^\n]",&par->temp_thres);
	fscanf(inpar,"%lf%*[^\n]",&par->vegphase12);
	fscanf(inpar,"%lf%*[^\n]",&par->vegphase23);
	fscanf(inpar,"%lf%*[^\n]",&par->photoper);
	fscanf(inpar,"%lf%*[^\n]",&par->phenolcount);

    ///Allocation
	fscanf(inpar,"%lf%*[^\n]",&par->C_stem_init);
	fscanf(inpar,"%lf%*[^\n]",&par->C_stor_init);
	fscanf(inpar,"%lf%*[^\n]",&par->glumax0);
	fscanf(inpar,"%lf%*[^\n]",&par->glumin0);
	fscanf(inpar,"%lf%*[^\n]",&par->SLA);
	fscanf(inpar,"%lf%*[^\n]",&par->root_per_leaf);
	fscanf(inpar,"%lf%*[^\n]",&par->root_turn);
	fscanf(inpar,"%lf%*[^\n]",&par->npp_frac);
	fscanf(inpar,"%lf%*[^\n]",&par->stor_bud);
	fscanf(inpar,"%lf%*[^\n]",&par->stor_stem);
	fscanf(inpar,"%lf%*[^\n]",&par->npp_stor);
	fscanf(inpar,"%lf%*[^\n]",&par->stor_day);
    fscanf(inpar,"%lf%*[^\n]",&par->perc_lai); // FG // GGI allocation
    fscanf(inpar,"%lf%*[^\n]",&par->npp_stor2); // FG // GGI allocation
    fscanf(inpar,"%lf%*[^\n]",&par->b_npp); // FG // GGI allocation
    fscanf(inpar,"%lf%*[^\n]",&par->alpha_npp); // FG // GGI allocation
    fscanf(inpar,"%lf%*[^\n]",&par->bud_tmax); // FG // GGI allocation
    fscanf(inpar,"%lf%*[^\n]",&par->b_bud_tmax); // FG // GGI allocation
    fscanf(inpar,"%lf%*[^\n]",&par->stor_moist_leaf1); // FG // GGI allocation
    fscanf(inpar,"%lf%*[^\n]",&par->bud_leaf_tmax); // FG // GGI allocation
    fscanf(inpar,"%lf%*[^\n]",&par->b_bud_leaf_tmax); // FG // GGI allocation
    fscanf(inpar,"%lf%*[^\n]",&par->PercCLeaf); // FG
    fscanf(inpar,"%lf%*[^\n]",&par->perc_lai_fall); // FG // GGI allocation
    fscanf(inpar,"%lf%*[^\n]",&par->LAI_pr); // FG
    fscanf(inpar,"%lf%*[^\n]",&par->LAI_temp); // FG
    fscanf(inpar,"%lf%*[^\n]",&par->phenol_sd);    // FG // GGI allocation
    fscanf(inpar,"%lf%*[^\n]",&par->phenol_alpha); // FG // GGI allocation
    fscanf(inpar,"%i%*[^\n]",&par->day23_flex); // FG
    fscanf(inpar, "%lf%*[^\n]", &par->CmaxSlope); // the slope of Cmax equation (Eq. 8 of GGI Biogeosciences)
    fscanf(inpar, "%lf%*[^\n]", &par->C_root_growth_min); // Minimum yearly carbon accumulation to the roots
    fscanf(inpar, "%i%*[^\n]", &par->yday_C_stor_stem); // In allocation period 2, all C goes to stem if NSC are at the maximum before this date
    fscanf(inpar, "%i%*[^\n]", &par->yday_C_stor_stem2); // In allocation period 2, all C goes to NSC after this date

	fclose(inpar);

	site->base_elev = par->base_elev; // see in Constants.h //FG
	site->base_isoh = par->base_isoh;
	site->site_lat = par->site_lat;
	site->site_elev = par->site_elev;
	site->site_slp = par->site_slp;
	site->site_asp = par->site_asp;
	site->site_isoh = par->site_isoh;
	site->site_ehoriz = par->site_ehoriz;
	site->site_whoriz = par->site_whoriz;
	site->tmax_lr = par->tmax_lr;
	site->tmin_lr = par->tmin_lr;
	//site->CO2_lr = CO2_lr_cst; // PAD 291008
	site->site_chf = par->site_chf;

	return (!ok);
}
/* end of read_init() */

//printf("read_init() ok\n");

// Copy files from one location to another, used in backup function
int FileCopy(const char *src, const char *dst)

// Function Name: FileCopy
//
// Copy the file specified by "src" to the file specified by "dst".
// Both source and destination file names must be full path/file names,
// such as c:\myfile.txt a:\myfile.txt.
//
// A more sophisticated version would make certain src and dst file names
// were complete and valid.  It would handle "wild card" characters to
// copy multiple files, and all sorts of goodies like that...but all those
// things destroy the "portability" of this code.
//
// This FileCopy function will work with virtually any ANSI C++ compiler.

 {
	#define BUFSZ 16000
	#define COPY_ERROR      -1
	#define COPY_OK          0

	char            *buf;
	FILE            *fi;
	FILE            *fo;
	unsigned        amount;
	unsigned        written;
	int             result;

	buf = new char[BUFSZ];

	fi = fopen( src, "rb" );
	fo = fopen( dst, "wb" );

	result = COPY_OK;
	if  ((fi == NULL) || (fo == NULL) )
	{
		result = COPY_ERROR;
		if (fi != NULL) fclose(fi);
		if (fo != NULL) fclose(fo);
	}

	if (result == COPY_OK)
	  {
	    do
	      {
		amount = fread( buf, sizeof(char), BUFSZ, fi );
		if (amount)
		  {
		    written = fwrite( buf, sizeof(char), amount, fo );
		    if (written != amount)
		      {
			result = COPY_ERROR; // out of disk space or some other disk err?
		      }
		  }
	      } // when amount read is < BUFSZ, copy is done
	    while ((result == COPY_OK) && (amount == BUFSZ));
	    fclose(fi);
	    fclose(fo);
	  }
	delete [] buf;
	return(result);
 }

int backup() // not use because done with reglage.py PAD 260209
{
	int ok=1;

	// Constructs Filenames

	const char *temp = "test";

	// Cedric: modifie ici si tu veux recuperer les output dans un directory a part
	//char *disksubdir =	"C:\\Laurent\\Modeles\\Maiden2.3\\";
	const char *disksubdir =	"/Users/pdanis/hd-ext/MAIDEN/4.1_iso/"; // PAD 241008 351

	// define variables for reading current time and date
	char current_timedate[128];
	time_t ltime;
	struct tm *today;
	char outputfolder[128], destination[128];

	// read current time and date and save in tmpbuf in yyyymmdd_hhmm format
	time(&ltime);
	today = localtime(&ltime);
	strftime(current_timedate, 128, "%Y%m%d_%H%M", today);

	// create new folder with current time and date for model output
	// misson 04/06/2005
	//sprintf(outputfolder,"%s%s%s%s",disksubdir,"model_output\\", current_timedate,"\\");
	//sprintf(outputfolder,"%s%s",disksubdir,"model_output\\");
	sprintf(outputfolder,"%s%s%s%s",disksubdir,"model_output", current_timedate,"/"); // PAD 241008
	sprintf(outputfolder,"%s%s",disksubdir,"model_output/");
	temp = outputfolder;
	printf("%s a creer dans Maiden.cpp ligne 371\n",temp);
	// _mkdir(temp); PAD 241008 368

	//printf("%s \n",outputfolder);

	//sprintf(outputfolder,"%s%s%s%s",disksubdir,"model_output\\", current_timedate,"\\");
	sprintf(outputfolder,"%s%s%s%s",disksubdir,"model_output/", current_timedate,"/"); // PAD 241008
	temp = outputfolder;
	// _mkdir(temp); PAD 241008 374

	//copy input, parameter file and canisotope_V3.1.cpp to output folder
	sprintf(destination,"%s%s",outputfolder,"inpar2.txt");
	FileCopy("inpar2.txt",destination);

	sprintf(destination,"%s%s",outputfolder,"inmet.txt");
	FileCopy("inmet.txt",destination);

	sprintf(destination,"%s%s",outputfolder,"Maiden.cpp");
	FileCopy("Maiden.cpp",destination);

	sprintf(destination,"%s%s",outputfolder,"allocation.cpp");
	FileCopy("allocation.cpp",destination);

	sprintf(destination,"%s%s",outputfolder,"meteorology.cpp");
	FileCopy("meteorology.cpp",destination);

	sprintf(destination,"%s%s",outputfolder,"phenology.cpp");
	FileCopy("phenology.cpp",destination);

	sprintf(destination,"%s%s",outputfolder,"photosynthesis_AL.cpp");
	FileCopy("photosynthesis_AL.cpp",destination);

	sprintf(destination,"%s%s",outputfolder,"radiation.cpp");
	FileCopy("radiation.cpp",destination);

	sprintf(destination,"%s%s",outputfolder,"soih2o.cpp");
	FileCopy("soih2o.cpp",destination);

	sprintf(destination,"%s%s",outputfolder,"soih2o_iso.cpp");
	FileCopy("soih2o_iso.cpp",destination);

	sprintf(destination,"%s%s",outputfolder,"isotopes.cpp");
	FileCopy("isotopes.cpp",destination);

	sprintf(destination,"%s%s",outputfolder,"soil_evap.cpp");
	FileCopy("soil_evap.cpp",destination);

	sprintf(destination,"%s%s",outputfolder,"throughfall.cpp");
	FileCopy("throughfall.cpp",destination);

	sprintf(destination,"%s%s",outputfolder,"transpiration.cpp");
	FileCopy("transpiration.cpp",destination);

	sprintf(destination,"%s%s",outputfolder,"Constants.h");
	FileCopy("Constants.h",destination);

	sprintf(destination,"%s%s",outputfolder,"maiden_funct.h");
	FileCopy("maiden_funct.h",destination);

	sprintf(destination,"%s%s",outputfolder,"maiden_struct.h");
	FileCopy("maiden_struct.h",destination);

	sprintf(destination,"%s%s",outputfolder,"outrad.txt");
	FileCopy("outrad.txt",destination);

	sprintf(destination,"%s%s",outputfolder,"outmet.txt");
	FileCopy("outmet.txt",destination);

	sprintf(destination,"%s%s",outputfolder,"outd18O_d.txt"); // PAD 131108
	FileCopy("outd18O_d.txt",destination);

    sprintf(destination,"%s%s",outputfolder,"outd18O_y.txt"); // PAD 131108
    FileCopy("outd18O_y.txt",destination);

	sprintf(destination,"%s%s",outputfolder,"outd2H.txt");  // PAD 131108
	FileCopy("outd2H.txt",destination);

	sprintf(destination,"%s%s",outputfolder,"outd13C_d.txt"); // PAD 131108
	FileCopy("outd13C_d.txt",destination);

    sprintf(destination,"%s%s",outputfolder,"outd13C_y.txt"); // PAD 131108
    FileCopy("outd13C_y.txt",destination);

	sprintf(destination,"%s%s",outputfolder,"outroot.txt"); // PAD 201108
	FileCopy("outroot.txt",destination);

	sprintf(destination,"%s%s",outputfolder,"outsoil.txt");
	FileCopy("outsoil.txt",destination);

	sprintf(destination,"%s%s",outputfolder,"outsnow.txt");
	FileCopy("outsnow.txt",destination);

	sprintf(destination,"%s%s",outputfolder,"outtemp.txt");
	FileCopy("outtemp.txt",destination);

	sprintf(destination,"%s%s",outputfolder,"outwater.txt");
	FileCopy("outwater.txt",destination);

	sprintf(destination,"%s%s",outputfolder,"outphoto.txt");
	FileCopy("outphoto.txt",destination);

	sprintf(destination,"%s%s",outputfolder,"outalloc_y.txt");
	FileCopy("outalloc_y.txt",destination);

	sprintf(destination,"%s%s",outputfolder,"outwatbalance.txt");
	FileCopy("outwatbalance.txt",destination);

	sprintf(destination,"%s%s",outputfolder,"outphenol.txt");
	FileCopy("outphenol.txt",destination);

	sprintf(destination,"%s%s",outputfolder,"outsim.txt");
	FileCopy("outsim.txt",destination);

	sprintf(destination,"%s%s",outputfolder,"outsoilev.txt");
	FileCopy("outsoilev.txt",destination);

	return (!ok);
}

/*****************************************************************/
/* data_alloc() allocates space for input and output data arrays */
/*****************************************************************/
int data_alloc(soilev_struct *soilev,meteo_struct *meteo,water_struct *water,
	       radiation_struct *rad, photo_struct *photo,
	       allocation_struct *alloc,
	       soil_struct *soil, water_an_struct *water_an, phenol_struct *phenol,
	       d18O_struct *d18O, d2H_struct *d2H, d13C_struct *d13C, const param_struct *par) // PAD 311008
{
	int ok=1;
	int l;
	int nyear;
	int m;
	//int BAD= 0; // or -9999  PAD 131108

	nyear = par->yearn - year0 + 1;

	if (ok && !(soilev->Epot		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (soilev->Epot)\n");ok=0;}
	if (ok && !(soilev->aird		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (soilev->aird)\n");ok=0;}
	if (ok && !(soilev->satmrl		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (soilev->satmrl)\n");ok=0;}
	if (ok && !(soilev->soilrhl		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (soilev->soilrhl)\n");ok=0;}
	if (ok && !(soilev->rsoil		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (soilev->rsoil)\n");ok=0;}
	if (ok && !(soilev->ra			= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (soilev->ra)\n");ok=0;}

	if (ok && !(meteo->year			= (int*) malloc(ndays * sizeof(int)))){printf("Error allocating (meteo->year)\n");ok=0;}
	if (ok && !(meteo->yday			= (int*) malloc(ndays * sizeof(int)))){printf("Error allocating (meteo->yday)\n");ok=0;}
	if (ok && !(meteo->tmax			= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->tmax)\n");ok=0;}
	if (ok && !(meteo->tmin			= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->tmin)\n");ok=0;}
	if (ok && !(meteo->prcp			= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->prcp)\n");ok=0;}
	if (ok && !(d18O->precip		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d18O->precip)\n");ok=0;} // PAD 281008
	if (ok && !(d18O->snowfall		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d18O->snowfall)\n");ok=0;} // PAD 050919
	if (ok && !(d18O->vapor		        = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d18O->vapor)\n");ok=0;} // PAD 281008
    if (ok && !(d18O->vapor_y                = (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (d18O->vapor_y)\n");ok=0;} // PAD 281008
	if (ok && !(d18O->Epot_through		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d18O->Epot_through)\n");ok=0;} // PAD 211108
	if (ok && !(d18O->Epot_through_snow	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d18O->Epot_through_snow)\n");ok=0;} // PAD 180719
	if (ok && !(d18O->cws		        = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d18O->cws)\n");ok=0;} // PAD 211108
	if (ok && !(d18O->css		        = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d18O->css)\n");ok=0;} // PAD 180719
	if (ok && !(d18O->through		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d18O->through)\n");ok=0;} // PAD 211108
	if (ok && !(d18O->through_snow	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d18O->through_snow)\n");ok=0;} // PAD 180719
	if (ok && !(d18O->infl		        = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d18O->infl)\n");ok=0;} // PAD 281008
	if (ok && !(d18O->soilevap	        = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d18O->soilevap)\n");ok=0;} // PAD 241108
	if (ok && !(d18O->snowevap	        = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d18O->snowevap)\n");ok=0;} // PAD 290819
	if (ok && !(d18O->xylem		        = (double*) malloc((ndays+1) * sizeof(double)))){printf("Error allocating (d18O->xylem)\n");ok=0;} // PAD 131108
    if (ok && !(d18O->xylem_y                = (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (d18O->xylem_y)\n");ok=0;} // PAD 131108
    if (ok && !(d18O->TRC                = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d18O->TRC)\n");ok=0;} // PAD 281008
    if (ok && !(d18O->TRC_y                = (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (d18O->TRC_y)\n");ok=0;} // PAD 281008
	if (ok && !(d2H->precip		        = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d2H->precip)\n");ok=0;} // PAD 121108
	if (ok && !(d2H->snowfall		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d2H->snowfall)\n");ok=0;} // PAD 050919
	if (ok && !(d2H->vapor		        = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d2H->vapor)\n");ok=0;} // PAD 121108
	if (ok && !(d2H->Epot_through		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d2H->Epot_through)\n");ok=0;} // PAD 211108
	if (ok && !(d2H->Epot_through_snow	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d2H->Epot_through_snow)\n");ok=0;} // PAD 180719
	if (ok && !(d2H->cws		        = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d2H->cws)\n");ok=0;} // PAD 211108
	if (ok && !(d2H->css		        = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d2H->css)\n");ok=0;} // PAD 180719
	if (ok && !(d2H->through		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d2H->through)\n");ok=0;} // PAD 211108
	if (ok && !(d2H->through_snow	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d2H->through_snow)\n");ok=0;} // PAD 180719
    if (ok && !(d2H->infl		        = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d2H->infl)\n");ok=0;} // PAD 121108
	if (ok && !(d2H->soilevap	        = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d2H->soilevap)\n");ok=0;} // PAD 241108
	if (ok && !(d2H->snowevap	        = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d2H->snowevap)\n");ok=0;} // PAD 290819
	if (ok && !(d2H->xylem		        = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d2H->xylem)\n");ok=0;} // PAD 131108
    if (ok && !(d2H->TRC                = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d2H->TRC)\n");ok=0;} // PAD 281008
    if (ok && !(d13C->stor                = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d13C->stor)\n");ok=0;} // PAD 210909
	if (ok && !(d13C->DTRC		        = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d13C->DTRC)\n");ok=0;} // PAD 220409
    if (ok && !(d13C->DTRC_y                = (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (d13C->DTRC_y)\n");ok=0;} // PAD 220409
	if (ok && !(d13C->TRCnew	        = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d13C->TRCnew)\n");ok=0;} // PAD 220409
    if (ok && !(d13C->TRCnew_y            = (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (d13C->TRCnew_y)\n");ok=0;} // PAD 220409
	if (ok && !(d13C->CCi_CO2	        = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d13C->CCi_CO2)\n");ok=0;} // PAD 180509
    if (ok && !(d13C->CCi_CO2_y            = (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (d13C->CCi_CO2_y)\n");ok=0;} // PAD 180509
    if (ok && !(d13C->CCa_CO2_y            = (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (d13C->CCa_CO2_y)\n");ok=0;} // PAD 180509
	if (ok && !(d13C->d13CO2		        = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (d13C->d13CO2)\n");ok=0;} // PAD 210909
    if (ok && !(d13C->d13CO2_y                = (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (d13C->d13CO2_y)\n");ok=0;} // PAD 210909
    if (ok && !(d13C->Cratio_y            = (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (d13C->Cratio_y)\n");ok=0;} // PAD 180509
	if (ok && !(meteo->CO2		        = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->CO2)\n");ok=0;} // PAD 291008
	if (ok && !(meteo->rad			= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->rad)\n");ok=0;}
	if (ok && !(meteo->rh			= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->rh)\n");ok=0;}
	if (ok && !(meteo->rhavg		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->rhavg)\n");ok=0;} // PAD 050809
	if (ok && !(meteo->ws			= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->ws)\n");ok=0;}
	if (ok && !(meteo->s_ws			= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->s_ws    )\n");ok=0;}
	if (ok && !(meteo->s_tmax		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->s_tmax)\n");ok=0;}
	if (ok && !(meteo->s_tmin		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->s_tmin)\n");ok=0;}
	if (ok && !(meteo->s_tavg		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->s_tavg)\n");ok=0;}
	if (ok && !(meteo->s_tday		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->s_tday)\n");ok=0;}
	if (ok && !(meteo->s_tday_transf= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->s_tday_transf)\n");ok=0;} //FG
	if (ok && !(meteo->s_prcp		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->s_prcp)\n");ok=0;}
	if (ok && !(meteo->s_prcp_snow	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->s_prcp_snow)\n");ok=0;}
	if (ok && !(meteo->s_hum		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->s_hum)\n");ok=0;}
	if (ok && !(meteo->s_srad		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->s_srad)\n");ok=0;}
	if (ok && !(meteo->s_par		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->s_par)\n");ok=0;}
	if (ok && !(meteo->s_dayl		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->s_dayl)\n");ok=0;}
	if (ok && !(meteo->s_swe		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->s_swe)\n");ok=0;}
	if (ok && !(meteo->s_pa			= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->s_pa    )\n");ok=0;}
	if (ok && !(meteo->s_avp		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->s_avp)\n");ok=0;}
	if (ok && !(meteo->s_svp		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->s_svp)\n");ok=0;}
	if (ok && !(meteo->s_gbh		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->s_gbh    )\n");ok=0;}
	if (ok && !(meteo->s_gbc		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->s_gbc)\n");ok=0;}
	if (ok && !(meteo->s_gaer		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->s_gaer)\n");ok=0;}
	if (ok && !(meteo->s_surft		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->s_surft)\n");ok=0;}
	if (ok && !(meteo->s_CO2 		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->s_CO2)\n");ok=0;}
	if (ok && !(meteo->srad_mtclim	        = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->srad_mtclim)\n");ok=0;}
	if (ok && !(meteo->avp_mtclim	        = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->avp_mtclim)\n");ok=0;}
	if (ok && !(meteo->dumvar		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->dumvar)\n");ok=0;}	//misson 112205

	if (ok && !(meteo->hs10		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->hs10)\n");ok=0;}
	if (ok && !(meteo->hs20		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->hs20)\n");ok=0;}
	if (ok && !(meteo->hs40		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->hs40)\n");ok=0;}
	if (ok && !(meteo->hs70		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (meteo->hs70    )\n");ok=0;}
	if (ok && !(meteo->T_previous_Y= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (meteo->T_previous_Y)\n");ok=0;}
	if (ok && !(meteo->Pspring= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (meteo->Pspring)\n");ok=0;}
    if (ok && !(meteo->T_previous_Y_sp= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (meteo->T_previous_Y_sp)\n");ok=0;}
	if (ok && !(meteo->Pspring_sp= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (meteo->Pspring_sp)\n");ok=0;}

	if (ok && !(water->srun		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->srun)\n");ok=0;}
	if (ok && !(water->ddr		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->ddr)\n");ok=0;}
	if (ok && !(water->pdirect	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->pdirect)\n");ok=0;}
	if (ok && !(water->psnowdirect	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->psnowdirect)\n");ok=0;}
	if (ok && !(water->through	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->through)\n");ok=0;}
	if (ok && !(water->through_snow	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->through_snow)\n");ok=0;}
	if (ok && !(water->canopy_snow	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->canopy_snow)\n");ok=0;}
	if (ok && !(water->se		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->se)\n");ok=0;}
	if (ok && !(water->ss		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->ss)\n");ok=0;}
	if (ok && !(water->ct		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->ct)\n");ok=0;}
	if (ok && !(water->trans_sun    = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->trans_sun)\n");ok=0;}
	if (ok && !(water->trans_shade	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->trans_shade)\n");ok=0;}
	if (ok && !(water->Epot_through = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->Epot_through)\n");ok=0;}
	if (ok && !(water->Epot_through_snow = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->Epot_through_snow)\n");ok=0;}
	if (ok && !(water->Epot_se	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->Epot_se)\n");ok=0;}
	if (ok && !(water->inf		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->inf)\n");ok=0;}
	if (ok && !(water->intercept	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->intercept)\n");ok=0;}
	if (ok && !(water->soil_rh	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->soil_rh)\n");ok=0;}
	if (ok && !(water->r_soil	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->r_soil)\n");ok=0;}
	if (ok && !(water->sat_mr	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->sat_mr)\n");ok=0;}
	if (ok && !(water->soil_mm	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->soil_mm)\n");ok=0;}
	if (ok && !(water->ice_mm	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->ice_mm)\n");ok=0;}
	if (ok && !(water->sm_stress	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->sm_stress)\n");ok=0;}

	//if (ok && !(water->sm_mean1		= (double*) malloc((ndays+1) * sizeof(double)))){printf("Error allocating ()\n");ok=0;} notused PAD 311008
	//if (ok && !(water->sm_mean2		= (double*) malloc((ndays+1) * sizeof(double)))){printf("Error allocating ()\n");ok=0;}
	if (ok && !(water->stress		= (double*) malloc((ndays+1) * sizeof(double)))){printf("Error allocating (water->stress)\n");ok=0;}
    if (ok && !(water->thaw_flag        = (int*) malloc(1 * sizeof(int)))){printf("Error allocating (water->thaw_flag)\n");ok=0;} // PAD 200322
    if (ok && !(water->thawed        = (int*) malloc(ndays * sizeof(int)))){printf("Error allocating (water->thawed)\n");ok=0;} // PAD 200322
    if (ok && !(water->icesnow	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->icesnow)\n");ok=0;}
	if (ok && !(water->h2osnow	= (double*) malloc((ndays+1) * sizeof(double)))){printf("Error allocating (water->h2osnow)\n");ok=0;}
    if (ok && !(water->dzsnow	= (double*) malloc((ndays+1) * sizeof(double)))){printf("Error allocating (water->dzsnow)\n");ok=0;}
	if (ok && !(d18O->snow	= (double*) malloc((ndays+1) * sizeof(double)))){printf("Error allocating (d18O->snow)\n");ok=0;} // PAD 190619
	if (ok && !(d2H->snow	= (double*) malloc((ndays+1) * sizeof(double)))){printf("Error allocating (d2H->snow)\n");ok=0;} // PAD 190619
	if (ok && !(d18O->snowwat	= (double*) malloc((ndays+1) * sizeof(double)))){printf("Error allocating (d18O->snowwat)\n");ok=0;} // PAD 190619
	if (ok && !(d2H->snowwat	= (double*) malloc((ndays+1) * sizeof(double)))){printf("Error allocating (d2H->snowwat)\n");ok=0;} // PAD 190619
	for (l=0;l<nslay;l++)
	{
	  if (ok && !(water->swp[l]	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (water->swp)\n");ok=0;}
	  if (ok && !(water->sm[l]	= (double*) malloc((ndays+1) * sizeof(double)))){printf("Error allocating (water->sm)\n");ok=0;}
	  if (ok && !(water->si[l]	= (double*) malloc((ndays+1) * sizeof(double)))){printf("Error allocating (water->si)\n");ok=0;}
	  if (ok && !(d18O->soil[l]	= (double*) malloc((ndays+1) * sizeof(double)))){printf("Error allocating (d18O->soil)\n");ok=0;} // PAD 121108
	  if (ok && !(d2H->soil[l]	= (double*) malloc((ndays+1) * sizeof(double)))){printf("Error allocating (d2H->soil)\n");ok=0;} // PAD 121108
	  if (ok && !(d18O->soilice[l]	= (double*) malloc((ndays+1) * sizeof(double)))){printf("Error allocating (d18O->soilice)\n");ok=0;} // PAD 190619
	  if (ok && !(d2H->soilice[l]	= (double*) malloc((ndays+1) * sizeof(double)))){printf("Error allocating (d2H->soilice)\n");ok=0;} // PAD 190619
 	}
	for (l=0;l<nslay_max;l++) //FG
	{
      if (ok && !(soil->root[l]	= (double*) malloc((ndays+1) * sizeof(double)))){printf("Error allocating (soil->root)\n");ok=0;} // PAD 201108
	}
	for (l=0;l<nslay_max+1;l++) //FG
	{
      if (ok && !(soil->temp[l]	= (double*) malloc((ndays+1) * sizeof(double)))){printf("Error allocating (soil->temp)\n");ok=0;}
	}
	if (ok && !(water_an->ct	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (water_an->ct)\n");ok=0;}
	if (ok && !(water_an->ddr	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (water_an->ddr)\n");ok=0;}
	if (ok && !(water_an->se	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (water_an->se)\n");ok=0;}
	if (ok && !(water_an->through	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (water_an->through)\n");ok=0;}
	if (ok && !(water_an->prcp	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (water_an->prcp)\n");ok=0;}
	if (ok && !(water_an->srun	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (water_an->srun)\n");ok=0;}
	if (ok && !(water_an->delta_sm	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (water_an->delta_sm)\n");ok=0;}
	if (ok && !(water_an->sm_initial= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (water_an->sm_initial)\n");ok=0;}
	if (ok && !(water_an->sm_final	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (water_an->sm_final)\n");ok=0;}
	if (ok && !(water_an->intercept	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (water_an->intercept)\n");ok=0;}
	if (ok && !(water_an->inf	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (water_an->inf)\n");ok=0;}
	if (ok && !(water_an->w_balance	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (water_an->w_balance)\n");ok=0;}

	if (ok && !(soil->swp		= (double*) malloc(nslay * sizeof(double)))){printf("Error allocating (soil->swp)\n");ok=0;}
	if (ok && !(soil->r		= (double*) malloc((nslay+1) * sizeof(double)))){printf("Error allocating (soil->r)\n");ok=0;}
	if (ok && !(soil->a		= (double*) malloc((nslay+1) * sizeof(double)))){printf("Error allocating (soil->a)\n");ok=0;}
	if (ok && !(soil->b		= (double*) malloc((nslay+1) * sizeof(double)))){printf("Error allocating (soil->b)\n");ok=0;}
	if (ok && !(soil->c		= (double*) malloc((nslay+1) * sizeof(double)))){printf("Error allocating (soil->c)\n");ok=0;}
	if (ok && !(soil->dwat		= (double*) malloc(nslay * sizeof(double)))){printf("Error allocating (soil->dwat)\n");ok=0;}

	if (ok && !(rad->ppfd_per_plaisun= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (rad->ppfd_per_plaisun)\n");ok=0;}
	if (ok && !(rad->ppfd_per_plaishade = (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (rad->ppfd_per_plaishade)\n");ok=0;}
	if (ok && !(rad->plaisun	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (rad->plaisun)\n");ok=0;}
	if (ok && !(rad->plaishade	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (rad->plaishade)\n");ok=0;}
	if (ok && !(rad->par_top	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (rad->par_top)\n");ok=0;}
	if (ok && !(rad->parabs		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (rad->parabs)\n");ok=0;}
	if (ok && !(rad->parabs_plaisun	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (rad->parabs_plaisun)\n");ok=0;}
	if (ok && !(rad->parabs_plaishade	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (rad->parabs_plaishade)\n");ok=0;}
	if (ok && !(rad->parabs_per_plaisun	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (rad->parabs_per_plaisun)\n");ok=0;}
	if (ok && !(rad->parabs_per_plaishade	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (rad->parabs_per_plaishade)\n");ok=0;}
	if (ok && !(rad->f_par_srad	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (rad->f_par_srad)\n");ok=0;}

	if (ok && !(photo->gb_c		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->gb_c)\n");ok=0;}
	if (ok && !(photo->Aj_sun	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->Aj_sun)\n");ok=0;}
	if (ok && !(photo->Av_sun	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->Av_sun)\n");ok=0;}
    if (ok && !(photo->A_sun		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->A_sun)\n");ok=0;}
	if (ok && !(photo->Cs_sun	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->Cs_sun)\n");ok=0;}
	if (ok && !(photo->gs_c_sun	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->gs_c_sun)\n");ok=0;}
	if (ok && !(photo->Ci_sun	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->Ci_sun)\n");ok=0;}
	if (ok && !(photo->Aj_shade	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->Aj_shade)\n");ok=0;}
	if (ok && !(photo->Av_shade	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->Av_shade)\n");ok=0;}
    if (ok && !(photo->A_shade		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->A_shade)\n");ok=0;}
	if (ok && !(photo->Cs_shade	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->Cs_shade)\n");ok=0;}
	if (ok && !(photo->gs_c_shade	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->gs_c_shade)\n");ok=0;}
	if (ok && !(photo->Ci_shade	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->Ci_shade)\n");ok=0;}
	if (ok && !(photo->A_sun_canopy	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->A_sun_canopy)\n");ok=0;}
	if (ok && !(photo->A_shade_canopy= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->A_shade_canopy)\n");ok=0;}
	if (ok && !(photo->A_canopy	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->A_canopy)\n");ok=0;}
	if (ok && !(photo->Km		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->Km)\n");ok=0;}
	if (ok && !(photo->Kc		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->Kc)\n");ok=0;}
	if (ok && !(photo->Ko		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->Ko)\n");ok=0;}
	if (ok && !(photo->O2		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->O2)\n");ok=0;}
	if (ok && !(photo->Vmax		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->Vmax)\n");ok=0;}
	if (ok && !(photo->gamma	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->gamma)\n");ok=0;}
	if (ok && !(photo->J_sun	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->J_sun)\n");ok=0;}
	if (ok && !(photo->J_shade	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->J_shade)\n");ok=0;}
	if (ok && !(photo->rh		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->rh)\n");ok=0;}
	if (ok && !(photo->vpd_stress	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->vpd_stress)\n");ok=0;}
	if (ok && !(photo->Rd_sun		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->Rd_sun)\n");ok=0;}
	if (ok && !(photo->Rd_shade		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->Rd_shade)\n");ok=0;}
	if (ok && !(photo->Rday			= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (photo->Rday)\n");ok=0;}

	if (ok && !(photo->N_opt_frac		= (double*) malloc(1 * sizeof(double)))){printf("Error allocating (photo->N_opt_frac)\n");ok=0;}
    if (ok && !(photo->stress1		= (double*) malloc(1 * sizeof(double)))){printf("Error allocating (photo->stress1)\n");ok=0;}  //ggi:08082014
	if (ok && !(alloc->spring_flag		= (int*) malloc(1 * sizeof(int)))){printf("Error allocating (alloc->spring_flag)\n");ok=0;}
	if (ok && !(alloc->fall_flag		= (int*) malloc(1 * sizeof(int)))){printf("Error allocating (alloc->fall_flag)\n");ok=0;}
	if (ok && !(alloc->c_immobilization_flag= (int*) malloc(1 * sizeof(int)))){printf("Error allocating (alloc->c_immobilization_flag)\n");ok=0;}
	if (ok && !(alloc->period		= (int*) malloc(ndays * sizeof(int)))){printf("Error allocating (alloc->period)\n");ok=0;}

	if (ok && !(alloc->C_leaf_growth	= (double*) malloc(1 * sizeof(double)))){printf("Error allocating (alloc->C_leaf_growth)\n");ok=0;}
	if (ok && !(alloc->C_root_growth	= (double*) malloc(1 * sizeof(double)))){printf("Error allocating (alloc->C_root_growth)\n");ok=0;}
	if (ok && !(alloc->C_stem_growth	= (double*) malloc(1 * sizeof(double)))){printf("Error allocating (alloc->C_stem_growth)\n");ok=0;}
	if (ok && !(alloc->C_leaf_max		= (double*) malloc(1 * sizeof(double)))){printf("Error allocating (alloc->C_leaf_max)\n");ok=0;}
	if (ok && !(alloc->Cmax		        = (double*) malloc(1 * sizeof(double)))){printf("Error allocating (alloc->Cmax)\n");ok=0;}
	if (ok && !(alloc->C_root_max		= (double*) malloc(1 * sizeof(double)))){printf("Error allocating (alloc->C_root_max)\n");ok=0;}
	if (ok && !(alloc->C_root_min		= (double*) malloc(1 * sizeof(double)))){printf("Error allocating (alloc->C_root_min)\n");ok=0;}
	if (ok && !(alloc->ratio_leaf		= (double*) malloc(1 * sizeof(double)))){printf("Error allocating (alloc->ratio_leaf)\n");ok=0;}
	if (ok && !(alloc->C_stor_1		= (double*) malloc(1 * sizeof(double)))){printf("Error allocating (alloc->C_stor_1    )\n");ok=0;}
	if (ok && !(alloc->C_stor_2		= (double*) malloc(1 * sizeof(double)))){printf("Error allocating (alloc->C_stor_2)\n");ok=0;}

	if (ok && !(alloc->inC_leaf		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (alloc->inC_leaf)\n");ok=0;}
	if (ok && !(alloc->inC_root		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (alloc->inC_root)\n");ok=0;}
	if (ok && !(alloc->inC_stem		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (alloc->inC_stem)\n");ok=0;}
	if (ok && !(alloc->inC_stor		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (alloc->inC_stor)\n");ok=0;}
	if (ok && !(alloc->outC_leaf	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (alloc->outC_leaf)\n");ok=0;}
	if (ok && !(alloc->outC_root	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (alloc->outC_root)\n");ok=0;}
	if (ok && !(alloc->outC_stem	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (alloc->outC_stem)\n");ok=0;}
	if (ok && !(alloc->outC_stor	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (alloc->outC_stor)\n");ok=0;}
	if (ok && !(alloc->dC_leaf		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (alloc->dC_leaf)\n");ok=0;}
	if (ok && !(alloc->dC_root		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (alloc->dC_root)\n");ok=0;}
	if (ok && !(alloc->dC_stem		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (alloc->dC_stem)\n");ok=0;}
	if (ok && !(alloc->dC_stor		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (alloc->dC_stor)\n");ok=0;}
	if (ok && !(alloc->glumax		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (alloc->glumax)\n");ok=0;}

	if (ok && !(alloc->LAI			= (double*) malloc((ndays+1) * sizeof(double)))){printf("Error allocating (alloc->LAI)\n");ok=0;}
	if (ok && !(alloc->C_leaf		= (double*) malloc((ndays+1) * sizeof(double)))){printf("Error allocating (alloc->C_leaf)\n");ok=0;}
	if (ok && !(alloc->C_root		= (double*) malloc((ndays+1) * sizeof(double)))){printf("Error allocating (alloc->C_root)\n");ok=0;}
	if (ok && !(alloc->C_stem		= (double*) malloc((ndays+1) * sizeof(double)))){printf("Error allocating (alloc->C_stem)\n");ok=0;}
	if (ok && !(alloc->C_stor		= (double*) malloc((ndays+1) * sizeof(double)))){printf("Error allocating (alloc->C_stor)\n");ok=0;}

	if (ok && !(alloc->leaf_gresp	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->leaf_gresp)\n");ok=0;}
	if (ok && !(alloc->root_gresp	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->root_gresp)\n");ok=0;}
	if (ok && !(alloc->stem_gresp	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->stem_gresp)\n");ok=0;}
	if (ok && !(alloc->stor_gresp	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->stor_gresp)\n");ok=0;}
	if (ok && !(alloc->GPP			= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->GPP)\n");ok=0;}
	if (ok && !(alloc->NPP			= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->NPP)\n");ok=0;}
	if (ok && !(alloc->MRESP		= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->MRESP)\n");ok=0;}
	if (ok && !(alloc->GRESP		= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->GRESP)\n");ok=0;}

	if (ok && !(alloc->auto_resp	= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (alloc->auto_resp)\n");ok=0;}
	if (ok && !(alloc->A_net		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (alloc->A_net)\n");ok=0;}

	if (ok && !(alloc->stemi		= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->stemi)\n");ok=0;}
	if (ok && !(alloc->LAI_year		= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->LAI_year    )\n");ok=0;}
	if (ok && !(alloc->C_leaf_year	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->C_leaf_year)\n");ok=0;}
	if (ok && !(alloc->C_root_year	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->C_root_year)\n");ok=0;}
	if (ok && !(alloc->C_stem_year	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->C_stem_year)\n");ok=0;}
	if (ok && !(alloc->C_stor_year	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->C_stor_year)\n");ok=0;}
	if (ok && !(alloc->inC_leaf_y	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->inC_leaf_y)\n");ok=0;}
	if (ok && !(alloc->outC_leaf_y	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->outC_leaf_y)\n");ok=0;}
	if (ok && !(alloc->inC_root_y	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->inC_root_y)\n");ok=0;}
	if (ok && !(alloc->outC_root_y	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->outC_root_y)\n");ok=0;}
	if (ok && !(alloc->inC_stem_y	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->inC_stem_y)\n");ok=0;}
	if (ok && !(alloc->outC_stem_y	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->outC_stem_y)\n");ok=0;}
	if (ok && !(alloc->inC_stor_y	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->inC_stor_y)\n");ok=0;}
	if (ok && !(alloc->outC_stor_y	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->outC_stor_y)\n");ok=0;}
	if (ok && !(alloc->stor_leaf	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->stor_leaf)\n");ok=0;}
	if (ok && !(alloc->stor_root	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->stor_root)\n");ok=0;}
	if (ok && !(alloc->stor_stem	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->stor_stem)\n");ok=0;}
	if (ok && !(alloc->npp_stor		= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->npp_stor)\n");ok=0;}
	if (ok && !(alloc->auto_resp_y	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->auto_resp_y)\n");ok=0;}
	if (ok && !(alloc->c_balance	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->c_balance)\n");ok=0;}
    if (ok && !(alloc->glumin		= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->glumin)\n");ok=0;}
    if (ok && !(alloc->Cmax2		= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->Cmax2)\n");ok=0;}
    if (ok && !(alloc->day3spr3sum  = (int*) malloc(nyear * sizeof(int)))){printf("Error allocating (alloc->day3spr3sum)\n");ok=0;}
    if (ok && !(alloc->LAImult		= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (alloc->LAImult)\n");ok=0;}

	if (ok && !(phenol->veg_phase	= (int*) malloc(ndays * sizeof(int)))){printf("Error allocating (phenol->veg_phase)\n");ok=0;}

	if (ok && !(phenol->sumdd		= (double*) malloc(ndays * sizeof(double)))){printf("Error allocating (phenol->sumdd)\n");ok=0;}

	if (ok && !(phenol->day12		= (int*) malloc(nyear * sizeof(int)))){printf("Error allocating (phenol->day12)\n");ok=0;}
	if (ok && !(phenol->day23		= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (phenol->day23)\n");ok=0;}
	if (ok && !(phenol->day23_sp	= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating (phenol->day23_sp)\n");ok=0;}
	if (ok && !(phenol->day34		= (int*) malloc(nyear * sizeof(int)))){printf("Error allocating (phenol->day34)\n");ok=0;}
	if (ok && !(phenol->day41		= (int*) malloc(nyear * sizeof(int)))){printf("Error allocating (phenol->day41)\n");ok=0;}
    //if (ok && !(phenol->T_previous_Y= (double*) malloc(nyear * sizeof(double)))){printf("Error allocating ()\n");ok=0;}

	if (ok && !(phenol->counter		= (int*) malloc(1 * sizeof(int)))){printf("Error allocating (phenol->counter)\n");ok=0;}

	for (m=0 ; m<ndays ; m++)
	{
        water->thawed[m]=0; // PAD 200322
        meteo->year[m]=0;
		meteo->yday[m]=0;
		meteo->tmax[m]=0;
		meteo->tmin[m]=0;
		meteo->prcp[m]=0;
		d18O->precip[m]=0;       // PAD 131108
		d18O->snowfall[m]=0;       // PAD 050919
		d18O->vapor[m]=0;        // PAD 131108
		d18O->Epot_through[m]=0; // PAD 211108
		d18O->Epot_through_snow[m]=0; // PAD 180719
		d18O->cws[m]=0;          // PAD 211108
		d18O->css[m]=0;          // PAD 180719
		d18O->through[m]=0;      // PAD 211108
		d18O->through_snow[m]=0; // PAD 180719
		d18O->infl[m]=0;         // PAD 131108
		d18O->xylem[m]=0;        // PAD 131108
		d18O->TRC[m]=0;          // PAD 141108
		d18O->soilevap[m]=0;     // PAD 141108
		d18O->snowevap[m]=0;     // PAD 290819
		for (l=0;l<nslay;l++)
		  {
		    d18O->soil[l][m]=0;  // PAD 131108
		    d18O->soilice[l][m]=0;  // PAD 190619
		  }
		d18O->snow[m]=0;  // PAD 190619
		d18O->snowwat[m]=0;  // PAD 190619
		//d18O->stor[m]=0;       // a faire
		d2H->precip[m]=0;        // PAD 131108
		d2H->snowfall[m]=0;       // PAD 050919
		d2H->vapor[m]=0;         // PAD 131108
		d2H->Epot_through[m]=0;  // PAD 211108
		d2H->Epot_through_snow[m]=0; // PAD 180719
		d2H->cws[m]=0;           // PAD 211108
		d2H->css[m]=0;           // PAD 180719
		d2H->through[m]=0;       // PAD 211108
		d2H->through_snow[m]=0;  // PAD 180719
		d2H->infl[m]=0;          // PAD 131108
		d2H->xylem[m]=0;         // PAD 131108
		d2H->TRC[m]=0;           // PAD 141108
		d2H->soilevap[m]=0;      // PAD 241108
		d2H->snowevap[m]=0;      // PAD 290819
		for (l=0;l<nslay;l++)
		  {
		    d2H->soil[l][m]=0;  // PAD 131108
		    d2H->soilice[l][m]=0;  // PAD 190619
		  }
		d2H->snow[m]=0;  // PAD 190619
		d2H->snowwat[m]=0;  // PAD 190619
		//d2H->stor[m]=0;        // a faire

		//d13C->leaf[m]=0; // PAD 131108 ??? proble segmentation fault ??
		//d13C->root[m]=0; // use compilation option -g
		//d13C->stem[m]=0; // gdb ./a.out
		d13C->d13CO2[m]=0; // run puis bt
		d13C->stor[m]=0; // run puis bt
		d13C->DTRC[m]=0;     // run puis bt
		d13C->TRCnew[m]=0;     // run puis bt
		d13C->CCi_CO2[m]=0; // run puis bt
		meteo->CO2[m]=0;         // PAD 291008
		meteo->rad[m]=0;
		meteo->rh[m]=0;
		meteo->rhavg[m]=0;      // PAD 050809
		meteo->ws[m]=0;
		meteo->s_ws[m]=0;
		meteo->s_tmax[m]=0;
		meteo->s_tmin[m]=0;
		meteo->s_tavg[m]=0;
		meteo->s_tday[m]=0;
		meteo->s_tday_transf[m]=0; //FG
		meteo->s_prcp[m]=0;
		meteo->s_prcp_snow[m]=0;
		meteo->s_hum[m]=0;
		meteo->s_srad[m]=0;
		meteo->s_par[m]=0;
		meteo->s_dayl[m]=0;
		meteo->s_swe[m]=0;
		meteo->s_pa[m]=0;
		meteo->s_avp[m]=0;
		meteo->s_svp[m]=0;
		meteo->s_gbh[m]=0;
		meteo->s_gbc[m]=0;
		meteo->s_gaer[m]=0;
		meteo->s_surft[m]=0;
		meteo->s_CO2[m]=0;
		meteo->hs10[m]=0;
		meteo->hs20[m]=0;
		meteo->hs40[m]=0;
		meteo->hs70[m]=0;
		meteo->avp_mtclim[m]=0;
		meteo->srad_mtclim[m]=0;

		water->srun[m]=0;
		water->ddr[m]=0;
		water->pdirect[m]=0;
		water->psnowdirect[m]=0;
		water->through[m]=0;
		water->through_snow[m]=0;
		water->canopy_snow[m]=0;
		water->se[m]=0;
		water->ss[m]=0;
		water->ct[m]=0;
		water->trans_sun[m]=0;
		water->trans_shade[m]=0;
		water->Epot_through[m]=0;
		water->Epot_through_snow[m]=0;
		water->Epot_se[m]=0;
		water->inf[m]=0;
		water->intercept[m]=0;
		water->soil_mm[m]=0;
		water->ice_mm[m]=0;
		water->soil_rh[m]=0;
		water->r_soil[m]=0;
		water->sat_mr[m]=0;
		water->stress[m]=0;
		water->sm_stress[m]=0;
		//water->sm_mean1[m]=0;  notused PAD 311008
		//water->sm_mean2[m]=0;
		for (l=0;l<nslay;l++)
		  {
		    water->sm[l][m]=0;
		    water->si[l][m]=0;
		    water->swp[l][m]=0;
		  }
		water->icesnow[m]=0;
		water->h2osnow[m]=0;
        water->dzsnow[m]=0;
		for (l=0;l<nslay_max;l++) //FG
            {
                soil->root[l][m]=0;  // PAD 201108
            }
		for (l=0;l<nslay_max+1;l++) //FG
            {
                soil->temp[l][m]=0;
            }
		rad->ppfd_per_plaisun[m]=0;
		rad->ppfd_per_plaishade[m]=0;
		rad->plaisun[m]=0;
		rad->plaishade[m]=0;
		rad->par_top[m]=0;
		rad->parabs[m]=0;
		rad->parabs_plaisun[m]=0;
		rad->parabs_plaishade[m]=0;
		rad->parabs_per_plaisun[m]=0;
		rad->parabs_per_plaishade[m]=0;
		rad->f_par_srad[m]=0;

		photo->gb_c[m]=0;
		photo->Aj_sun[m]=0;
		photo->Av_sun[m]=0;
		photo->A_sun[m]=0;
		photo->Cs_sun[m]=0;
		photo->gs_c_sun[m]=0;
		photo->Ci_sun[m]=0;
		photo->Aj_shade[m]=0;
		photo->Av_shade[m]=0;
		photo->A_shade[m]=0;
		photo->Cs_shade[m]=0;
		photo->gs_c_shade[m]=0;
		photo->Ci_shade[m]=0;
		photo->A_sun_canopy[m]=0;
		photo->A_shade_canopy[m]=0;
		photo->A_canopy[m]=0;
		photo->Km[m]=0;
		photo->Kc[m]=0;
		photo->Ko[m]=0;
		photo->O2[m]=0;
		photo->Vmax[m]=0;
		photo->gamma[m]=0;
		photo->J_sun[m]=0;
		photo->J_shade[m]=0;
		photo->rh[m]=0;
		photo->vpd_stress[m]=0;
		photo->Rd_sun[m]=0;
		photo->Rd_shade[m]=0;
		photo->Rday[m]=0;

		alloc->LAI[m]=0;
		alloc->C_leaf[m]=0;
		alloc->C_root[m]=0;
		alloc->C_stem[m]=0;
		alloc->C_stor[m]=0;

		alloc->inC_leaf[m]=0;
		alloc->inC_root[m]=0;
		alloc->inC_stem[m]=0;
		alloc->inC_stor[m]=0;
		alloc->outC_leaf[m]=0;
		alloc->outC_root[m]=0;
		alloc->outC_stem[m]=0;
		alloc->outC_stor[m]=0;
		alloc->dC_leaf[m]=0;
		alloc->dC_root[m]=0;
		alloc->dC_stem[m]=0;
		alloc->dC_stor[m]=0;
		alloc->period[m]=0;
		alloc->glumax[m]=0;
		alloc->auto_resp[m]=0;
		alloc->A_net[m]=0;

		phenol->veg_phase[m]=0;
		phenol->sumdd[m]=0;
	}

 	for (m=0; m<nyear; m++)
	{
	    meteo->T_previous_Y[m]=0;
        meteo->Pspring[m]=0;
	    meteo->T_previous_Y_sp[m]=0;
        meteo->Pspring_sp[m]=0;

		water_an->ct[m]=0;
		water_an->ddr[m]=0;
		water_an->se[m]=0;
		water_an->through[m]=0;
		water_an->prcp[m]=0;
		water_an->srun[m]=0;
		water_an->delta_sm[m]=0;
		water_an->sm_initial[m]=0;
		water_an->sm_final[m]=0;
		water_an->intercept[m]=0;
		water_an->inf[m]=0;
		water_an->w_balance[m]=0;

        d13C->CCa_CO2_y[m]=0;
        d13C->CCi_CO2_y[m]=0;
        d13C->d13CO2_y[m]=0;
        d13C->DTRC_y[m]=0;
        d13C->TRCnew_y[m]=0;
        d13C->Cratio_y[m]=0;

        d18O->vapor_y[m]=0;
        d18O->xylem_y[m]=0;
        d18O->TRC_y[m]=0;

		alloc->leaf_gresp[m]=0;
		alloc->root_gresp[m]=0;
		alloc->stem_gresp[m]=0;
		alloc->stor_gresp[m]=0;
		alloc->GPP[m]=0;
		alloc->NPP[m]=0;
		alloc->MRESP[m]=0;
		alloc->GRESP[m]=0;
		alloc->LAI_year[m]=0;
		alloc->stemi[m]=0;
		alloc->C_leaf_year[m]=0;
		alloc->C_root_year[m]=0;
		alloc->C_stem_year[m]=0;
		alloc->C_stor_year[m]=0;
		alloc->inC_leaf_y[m]=0;
		alloc->outC_leaf_y[m]=0;
		alloc->inC_root_y[m]=0;
		alloc->outC_root_y[m]=0;
		alloc->inC_stem_y[m]=0;
		alloc->outC_stem_y[m]=0;
		alloc->inC_stor_y[m]=0;
		alloc->outC_stor_y[m]=0;
		alloc->stor_leaf[m]=0;
		alloc->stor_root[m]=0;
		alloc->npp_stor[m]=0;
		alloc->stor_stem[m]=0;
		alloc->auto_resp_y[m]=0;
		alloc->c_balance[m]=0;
        alloc->glumin[m]=0;
        alloc->Cmax2[m]=0;
        alloc->day3spr3sum[m]=0;
        alloc->LAImult[m]=0;

		phenol->day12[m]=0;
		phenol->day23[m]=0;
		phenol->day23_sp[m]=0;
		phenol->day34[m]=0;
		phenol->day41[m]=0;
		//phenol->T_previous_Y[m]=0;

	}

 	for (m=0; m<nslay+1; m++) // inutile ??? pas fct layer PAD 201108
	  {
	    soil->r[m]=0;
	    soil->a[m]=0;
	    soil->b[m]=0;
	    soil->c[m]=0;
	  }
 	for (m=0; m<nslay; m++) // inutile ??? pas fct layer PAD 201108
	  {
	    soil->swp[m]=0;
	    soil->dwat[m]=0;
	  }

	alloc->spring_flag[0]=0;
	alloc->fall_flag[0]=0;
	alloc->c_immobilization_flag[0]=0;
    water->thaw_flag[0]=0; // PAD 200322

	alloc->C_leaf_growth[0]=0;
	alloc->C_root_growth[0]=0;
	alloc->C_stem_growth[0]=0;
	alloc->C_leaf_max[0]=0;
	alloc->Cmax[0]=0;
	alloc->C_root_max[0]=0;
	alloc->C_root_min[0]=0;
	alloc->ratio_leaf[0]=0;
	alloc->C_stor_1[0]=0;
	alloc->C_stor_2[0]=0;
    photo->stress1[0]=1.0;  //ggi: 08082014
	photo->N_opt_frac[0]=0;
	phenol->counter[0]=0;

    printf("data_alloc() ok\n");

	return (!ok);
}
/* end of data_alloc() */



/**************************************************************************/
/* read_inmet() reads data from the meteorological input file into arrays */
/**************************************************************************/
int read_inmet(meteo_struct *meteo, water_struct *water, param_struct *par,
           d18O_struct *d18O, d2H_struct *d2H, d13C_struct *d13C)
{
    int ok=1;
    int i;//j canceled FG
    char header[400];
    //char where[5]; put in Maiden_struct.h PAD 020309
    double co2_0;//tmean,co2_1,co2_2,co2_3 canceled FG
    //printf("par->meteo_site : %i par->d18O_flag : %i (read_inmet in Maiden)\n",par->meteo_site,par->d18O_flag);
    /* read header lines and discard */
    fgets(header,400,inmet);
    i=strlen(header);
    header[--i] = '\0'; //needed to drop '\n' at the end of header
    printf("header= %s (in Maiden.cpp line 1214)\n",header);

    if (strcmp(header,"year-day-tmax-tmin-rad-prec-rhavg-wind-CO2") == 0)
        par->meteo_site = 1;
    else if (strcmp(header,"year-day-tmax-tmin-prec-CO2") == 0)
        par->meteo_site = 2;
    else if (strcmp(header,"year-day-tmax-tmin-prec-CO2-d18Op-d18Ov") == 0)
        par->meteo_site = 3;
    else if (strcmp(header,"year-day-tmax-tmin-prec-CO2-d13C") == 0)
        par->meteo_site = 4;
    else if (strcmp(header,"QPFFN-XXXX-XXXX-Obs-Adjusted-No-RIEN") == 0) //to be able to use the old inmets
        par->meteo_site = 4;
    else
    {
        par->meteo_site = 0;
        printf("UNKNOWN HEADER OPTION IN inmet.txt\n");
        return(1);
    }

    printf("d18O_flag      = %i       (Maiden 1319)\n",par->d18O_flag);
    printf("CO2_flag       = %i       (idem)\n",par->CO2_flag);
    printf("meteo_site     = %i       (idem)\n",par->meteo_site);
    printf("exp_site       = %i       (idem)\n",exp_site);

    /* read lines of data */
    i = 0;
    while (ok && i<ndays)
    {   /*
        Tmax, Tmin (C)
        Global Radiation (W/m2)
        Precipitation (cm)
        Relative Humidity (1)
        Wind Speed (m/s)
        CO2 (ppmV)
        d18Op d18Ov (permil) */
        /* Simulation with MAIDEN without considering isotopes PAD 291008 */
        if (par->meteo_site == 1) // 1: complete
        {
            fscanf(inmet, "%d %d %lf %lf %lf %lf %lf %lf %lf\n",
                   &(meteo->year[i]),&(meteo->yday[i]),
                   &(meteo->tmax[i]),&(meteo->tmin[i]),&(meteo->rad[i]),
                   &(meteo->prcp[i]),&(meteo->rhavg[i]),&(meteo->ws[i]),
                   &(meteo->CO2[i]));
            //meteo->CO2[i] = 375.; // PAD 131108
        }
        else if (par->meteo_site == 2) // 2: reduced
        {
            fscanf(inmet, "%d %d %lf %lf %lf %lf\n",
                   &(meteo->year[i]), &(meteo->yday[i]),
                   &(meteo->tmax[i]), &(meteo->tmin[i]),
                   &(meteo->prcp[i]), &(meteo->CO2[i]));
        }
        else if (par->meteo_site == 3) // 3: REMOrediso PAD 131108
        {
            fscanf(inmet, "%d %d %lf %lf %lf %lf %lf %lf\n",
                   &(meteo->year[i]), &(meteo->yday[i]),
                   &(meteo->tmax[i]), &(meteo->tmin[i]),
                   &(meteo->prcp[i]), &(meteo->CO2[i]),
                   &(d18O->precip[i]), &(d18O->vapor[i]));

            if (i==0) printf("**** Meteo from REMOiso with d18OP and d18OV ****\n");// PAD 180809
        }
        else if (par->meteo_site == 4) // 4: with d13CO2 from SCRIPPS
        {
            fscanf(inmet, "%d %d %lf %lf %lf %lf %lf\n",
                   &(meteo->year[i]), &(meteo->yday[i]),
                   &(meteo->tmax[i]), &(meteo->tmin[i]),
                   &(meteo->prcp[i]),&(meteo->CO2[i]),
                   &(d13C->d13CO2[i]));
        }

        if (meteo->rhavg[i] > 1.)
        {
            printf("RH greater than 100 in Maiden.cpp\n");
            printf("RH : %lf\n",meteo->rhavg[i]) ;
            meteo->rhavg[i] = 1.;
        }
        if (meteo->tmax[i] == meteo->tmin[i])
        {
            meteo->tmax[i] = meteo->tmax[i] + 0.01 ;
        }
        if (meteo->tmax[i] <= meteo->tmin[i])
        {
            printf("Tmin greater than Tmax in Maiden.cpp (solved by switching), day %d\n",i);
            //meteo->tmax[i] = meteo->tmax[i] + 0.01 ; //switching Tmin and Tmax is better
            co2_0 = meteo->tmax[i];
            meteo->tmax[i] = meteo->tmin[i];
            meteo->tmin[i] = co2_0;
        }

        i++;
    } /* end while */

    /* check for gaps in yearday field */
    i = 1;
    while (ok && i<ndays)
    {
        if (meteo->yday[i] != 1) /* not January 1 */
        {
            if (meteo->yday[i] != (meteo->yday[i-1]+1))
            {
                printf("%d %i\n",meteo->year[i],meteo->yday[i]);
                printf("Gap in yeardays at line #%d\n",i+1);
                ok=0;
            }
        }
        else /* January 1 */
        {
            if ((meteo->yday[i-1] != 365) && (meteo->yday[i-1] != 366))
            {
                printf("%i %i\n",meteo->year[i],meteo->yday[i]);
                printf("Gap in yeardays at line #%d\n",i+1);
                ok=0;
            }
        }
        i++;
    }

    fclose(inmet);

    return (!ok);
}
/* end of read_inmet() */


/************************************/
/* write_out writes the output file */
/************************************/
int write_out(const meteo_struct *meteo,const soil_struct *soil,
	      const water_struct *water,
	      const radiation_struct *rad, const photo_struct *photo,
	      const allocation_struct *alloc, const water_an_struct *water_an,
	      const phenol_struct *phenol,
	      const soilev_struct *soilev,
	      const d18O_struct *d18O, const d2H_struct *d2H,
	      const d13C_struct *d13C, const param_struct *par)
{
	int ok=1;
	int y,z;
	int day0;
	int dayn;//,nyear_sim FG canceled
	int i=0;
	double var_sim, var_mean, Ny;
    int outmetPrint,outd18O_dayPrint,outd18O_yearPrint,outd2HPrint,outd13C_dayPrint,outd13C_yearPrint,outrootPrint,outsoilPrint,outsnowPrint,outtempPrint,outsoilevPrint,outwaterPrint,outphenolPrint,outradPrint,outphotoPrint,outwatbalancePrint,outalloc_yearPrint,outalloc_dayPrint,outsimPrint,outcustomPrint;

    if ((exportflags = fopen("exportflags.txt", "r"))) {
        fscanf(exportflags,"%i%*[^\n]",&outmetPrint);
        fscanf(exportflags,"%i%*[^\n]",&outd18O_dayPrint);
        fscanf(exportflags,"%i%*[^\n]",&outd18O_yearPrint);
        fscanf(exportflags,"%i%*[^\n]",&outd2HPrint);
        fscanf(exportflags,"%i%*[^\n]",&outd13C_dayPrint);
        fscanf(exportflags,"%i%*[^\n]",&outd13C_yearPrint);
        fscanf(exportflags,"%i%*[^\n]",&outrootPrint);
        fscanf(exportflags,"%i%*[^\n]",&outsoilPrint);
        fscanf(exportflags,"%i%*[^\n]",&outsnowPrint);
        fscanf(exportflags,"%i%*[^\n]",&outtempPrint);
        fscanf(exportflags,"%i%*[^\n]",&outsoilevPrint);
        fscanf(exportflags,"%i%*[^\n]",&outwaterPrint);
        fscanf(exportflags,"%i%*[^\n]",&outphenolPrint);
        fscanf(exportflags,"%i%*[^\n]",&outradPrint);
        fscanf(exportflags,"%i%*[^\n]",&outphotoPrint);
        fscanf(exportflags,"%i%*[^\n]",&outwatbalancePrint);
        fscanf(exportflags,"%i%*[^\n]",&outalloc_yearPrint);
        fscanf(exportflags,"%i%*[^\n]",&outalloc_dayPrint);
        fscanf(exportflags,"%i%*[^\n]",&outsimPrint);
        fscanf(exportflags,"%i%*[^\n]",&outcustomPrint);
        fclose(exportflags);
        printf("Reading export flags from exportflags.txt\n");
	} else {
        printf("No exportflags.txt found: Exporting defaults.\n");
        ///Decide what to print
        outmetPrint=1;
        outd18O_dayPrint=1;
        outd18O_yearPrint=1;
        outd2HPrint=1;
        outd13C_dayPrint=1;
        outd13C_yearPrint=1;
        outrootPrint=1;
        outsoilPrint=1;
        outsnowPrint=1;
        outtempPrint=1;
        outsoilevPrint=1;
        outwaterPrint=1;
        outphenolPrint=1;
        outradPrint=1;
        outphotoPrint=1;
        outwatbalancePrint=1;
        outalloc_yearPrint=1;
        outalloc_dayPrint=1;
        outsimPrint=1;
        outcustomPrint=0;
    }
	printf("Start write_out (Maiden)");

	day0 = 365 * (par->year0_sim-year0);
	dayn = day0 + (365 * (par->yearn_sim-par->year0_sim+1));

	//nyear_sim = yearn_sim - (year0_sim - 1); FG

    if (outmetPrint == 1)
    {
        outmet = fopen("outmet.txt","w");
        fprintf(outmet,"%6s%6s%8s%8s%8s%8s%8s%8s%8s%9s%9s%8s%8s%8s%8s%8s%8s%8s%8s%8s%8s%8s%8s%8s%8s%8s%8s%8s\n",
            "year","day","Tmax","Tmin","Tavg","Tday","TdayTr","rain","snow","VPD","srad","daylen","PAR","gbh","gaer"," svp"," avp"," avp_mtclim"," srad_mtclim"," soilmm"," wstress"," vpdstress"," atms_p"," PARsun"," PARshade"," CO2"," RH?"," RHavg");
        for (i=day0 ; i<dayn ; i++)
        {
          fprintf(outmet,"%4d %3d %8.2lf%8.2lf%8.2lf%8.2lf%8.2lf%8.2lf%9.2lf%9.2lf%9.2lf%14.0lf%14.2lf%14.2lf%14.2lf%14.2lf%14.2lf%14.2lf%14.2lf%14.2lf%14.2lf%14.2lf%14.2lf%14.2lf%14.2lf%14.2lf%14.2lf%14.2lf\n",
              meteo->year[i],meteo->yday[i],meteo->s_tmax[i],meteo->s_tmin[i],
              meteo->s_tavg[i],meteo->s_tday[i], meteo->s_tday_transf[i],
              meteo->s_prcp[i],meteo->s_prcp_snow[i],meteo->s_hum[i],meteo->s_srad[i],meteo->s_dayl[i],
              meteo->s_par[i],meteo->s_gbh[i],meteo->s_gaer[i],
              meteo->s_svp[i],meteo->s_avp[i],meteo->avp_mtclim[i],
              meteo->srad_mtclim[i],water->soil_mm[i],water->stress[i],
              photo->vpd_stress[i],meteo->s_pa[i],
              rad->ppfd_per_plaisun[i],rad->ppfd_per_plaishade[i],
              meteo->s_CO2[i],meteo->rh[i],meteo->rhavg[i]); // PAD 270209
        }
        fclose(outmet);
    }

	/********************************/
	/* d18O outputs file PAD 131108 */
	/********************************/
	if (outd18O_dayPrint == 1)
    {
        outd18O_day = fopen("outd18O_d.txt","w");
        if (nslay == 4) {
        // fprintf(outd18O,"%6s%6s%8s%10s%8s%8s%8s%8s%8s%11s%9s%12s%13s\n",
        fprintf(outd18O_day,"%s\t%s\t\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\n",
                  "year","day","d18Orainfall","d18Osnowfall","d18Oxylem",
                  "d18Osnow","d18Osnowwat","d18Osw1","d18Osw2","d18Osw3","d18Osw4","d18OTRC","d18Ocanwat","d18Ocansnow","d18Oevap","d18Othrough","d18Ovapor","d18Osoilevap","d18Osnowevap");

            for (i=day0 ; i<dayn ; i++)
            {
                //printf("%i d18O soil 2  %8.2lf      (maiden 1253)\n",i, d18O->soil[1][i]);
                fprintf(outd18O_day,"%6d\t%6d\t%10.2lf\t%10.2lf\t%10.2lf\t%10.2lf\t%10.2lf\t%10.2lf\t%10.2lf\t%10.2lf\t%10.2lf\t%10.2lf\t%10.2lf\t%10.2lf\t%10.2lf\t%10.2lf\t%10.2lf\t%10.2lf\t%10.2lf\n",
                      meteo->year[i],meteo->yday[i],
                      d18O->precip[i],d18O->snowfall[i],d18O->xylem[i],
                      d18O->snow[i],d18O->snowwat[i],
                      d18O->soil[0][i],d18O->soil[1][i],
                      d18O->soil[2][i],d18O->soil[3][i],
                      d18O->TRC[i],
                      d18O->cws[i],d18O->css[i],d18O->Epot_through[i],d18O->through[i],
                      d18O->vapor[i],d18O->soilevap[i],d18O->snowevap[i]);
            }
        }
        if (nslay == 5){
            fprintf(outd18O_day,"%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\n",
                  "year","day","d18Orainfall","d18Osnowfall","d18Oxylem",
                  "d18Osnow","d18Osnowwat","d18Osw1","d18Osw2","d18Osw3","d18Osw4","d18Osw5","d18OTRC","d18Ocanopy","d18Oevap","d18Othrough","d18Osoilevap");

            for (i=day0 ; i<dayn ; i++)
            {
                fprintf(outd18O_day,"%6d%6d%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf\n",
                      meteo->year[i],meteo->yday[i],
                      d18O->precip[i],d18O->snowfall[i],d18O->xylem[i],
                      d18O->snow[i],d18O->snowwat[i],
                      d18O->soil[0][i],d18O->soil[1][i],
                      d18O->soil[2][i],d18O->soil[3][i],d18O->soil[4][i],
                      d18O->TRC[i],
                      d18O->cws[i],d18O->Epot_through[i],d18O->through[i],
                      d18O->vapor[i],d18O->soilevap[i]);
            }
        }
        fclose(outd18O_day);
    }

    if (outd18O_yearPrint == 1)
    {
        outd18O_year = fopen("outd18O_y.txt","w");
        z = par->year0_sim;
        fprintf(outd18O_year,"year d18Ostem d18OGPP d18Oxylem d18Ovapor\n");

        for (y=(par->year0_sim-year0) ; y<(par->yearn_sim-year0+1) ; y++)
        {
            d18O->TRC_y[y] = d18O->TRC_y[y] / alloc->stemi[y];  ///alloc->NPP[y];
            d18O->xylem_y[y] = d18O->xylem_y[y] / 365;  ///alloc->NPP[y];
            d18O->vapor_y[y] = d18O->vapor_y[y] / 365;

            var_mean = 0.;
            for (i=(365*y) ; i<(365*y+365) ; i++)
            { var_mean = var_mean + d18O->TRC[i]*photo->A_canopy[i]; }
            var_mean = var_mean/alloc->GPP[y] ;

            fprintf(outd18O_year,"%6d%12.2lf%12.2lf%12.2lf%12.3lf\n",
                    z,d18O->TRC_y[y],var_mean,d18O->xylem_y[y],d18O->vapor_y[y]);
            z = z + 1;
        }
        fclose(outd18O_year);
    }

	/********************************/
	/* d2H outputs file PAD 131108 */
	/********************************/
    if (outd2HPrint == 1)
    {
        outd2H = fopen("outd2H.txt","w");
        if (nslay == 4) {
            //fprintf(outd2H,"%6s%6s%8s%10s%8s%8s%8s%8s%8s%8s%8s%11s%9s%12s%13s%13s\n",
            fprintf(outd2H,"%s\t%s\t\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\n",
                "year","day","d2Hp","d2Hxylem",
                "d2Hsnow","d2Hsnowwat","d2Hsw1","d2Hsw2","d2Hsw3","d2Hsw4","d2HTRC","d2Hcanopy","d2Hevap","d2Hthrough","d2Hvapor","d2Hsoilevap","d2Hsnowevap");

            for (i=day0 ; i<dayn ; i++)
            {
              //printf("%i d2H soil 2  %8.2lf      (maiden 1253)\n",i, d2H->soil[1][i]);
              fprintf(outd2H,"%6d%6d%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf\t%10.2lf%10.2lf\n",
                  meteo->year[i],meteo->yday[i],
                  d2H->precip[i],d2H->xylem[i],
                  d2H->snow[i],d2H->snowwat[i],
                  d2H->soil[0][i],d2H->soil[1][i],
                  d2H->soil[2][i],d2H->soil[3][i],
                  d2H->TRC[i],
                  d2H->cws[i],d2H->Epot_through[i],d2H->through[i],
                  d2H->vapor[i],d2H->soilevap[i],d2H->snowevap[i]);
            }
        }
 //       if (nslay == 5){
//          fprintf(outd2H,"%6s%6s%8s%10s%8s%8s%8s%8s%8s%8s%8s%8s%11s%9s%12s%13s%13s\n",
 //             "year","day","d2Hp","d2Hxylem",
//              "d2Hsnow","d2Hsnowwat","d2Hsw1","d2Hsw2","d2Hsw3","d2Hsw4","d2Hsw5","d2HTRC","d2Hcanopy","d2Hevap","d2Hthrough","d2Hvapor","d2Hsoilevap"); // FG

 //         for (i=day0 ; i<dayn ; i++)
 //           {
              //printf("%i d2H soil 2  %8.2lf      (maiden 1253)\n",i, d2H->soil[1][i]);
 //             fprintf(outd2H,"%6d%6d%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf%10.2lf\n",
  //                meteo->year[i],meteo->yday[i],
  //                d2H->precip[i],d2H->xylem[i],
  //                d2H->snow[i],d2H->snowwat[i],
  //                d2H->soil[0][i],d2H->soil[1][i],
   //               d2H->soil[2][i],d2H->soil[3][i],d2H->soil[4][i],
  //                d2H->TRC[i],
 //                 d2H->cws[i],d2H->Epot_through[i],d2H->through[i],
  //                d2H->vapor[i],d2H->soilevap[i]);
 //           }
 //       }
        fclose(outd2H);
    }

	/********************************/
	/* d13C outputs file PAD 131108 */
	/********************************/
    if (outd13C_dayPrint == 1)
    {
        outd13C_day = fopen("outd13C_d.txt","w");
        fprintf(outd13C_day,"year day Dd13C_TRC newd13Cstem d13C_stor d13C_CO2 alloc_stem CCi_CO2-ppmV CCa_CO2-ppmV\n");

        for (i=day0 ; i<dayn ; i++)
        {
            //printf("%i Dd13C:%8.2lf (maiden 1435)\n",i,d13C->DTRC[i]);
            fprintf(outd13C_day,"%6d%6d%10.2lf%10.3lf%10.3lf%10.3lf%10.3lf%10.2lf%10.2lf\n",
                meteo->year[i],meteo->yday[i],
                d13C->DTRC[i],d13C->TRCnew[i],d13C->stor[i],d13C->d13CO2[i],alloc->inC_stem[i],d13C->CCi_CO2[i],meteo->s_CO2[i]);
        }
        fclose(outd13C_day);
    }

    if (outd13C_yearPrint == 1)
    {
        outd13C_year = fopen("outd13C_y.txt","w");
        z = par->year0_sim;
        fprintf(outd13C_year,"year D13C d13Cstem d13CGPP d13CO2 CCi_CO2-ppmV CCa_CO2-ppmV C_ratio\n");

        for (y=(par->year0_sim-year0) ; y<(par->yearn_sim-year0+1) ; y++)
        {
            d13C->DTRC_y[y] = d13C->DTRC_y[y] / alloc->stemi[y];  // alloc->NPP[y];
            d13C->TRCnew_y[y] = d13C->TRCnew_y[y] / alloc->stemi[y];  ///alloc->NPP[y];
            d13C->CCi_CO2_y[y] = d13C->CCi_CO2_y[y] / alloc->stemi[y];  ///alloc->NPP[y];
            d13C->CCa_CO2_y[y] = d13C->CCa_CO2_y[y] / alloc->stemi[y];  ///alloc->NPP[y];
            d13C->d13CO2_y[y] = d13C->d13CO2_y[y] / 365;
            d13C->Cratio_y[y] = d13C->CCi_CO2_y[y] / d13C->CCa_CO2_y[y];

            var_mean = 0.;
            for (i=(365*y) ; i<(365*y+365) ; i++)
            { var_mean = var_mean + d13C->TRCnew[i]*photo->A_canopy[i]; }
            var_mean = var_mean/alloc->GPP[y] ;

            fprintf(outd13C_year,"%6d%12.2lf%12.2lf%12.2lf%12.2lf%12.2lf%12.2lf%12.3lf\n",
                    z,d13C->DTRC_y[y],d13C->TRCnew_y[y],var_mean,d13C->d13CO2_y[y],d13C->CCi_CO2_y[y],d13C->CCa_CO2_y[y],d13C->Cratio_y[y]);
            z = z + 1;
        }
        fclose(outd13C_year);
    }

	/********************************/
	/* Root outputs file PAD 201108 */
	/********************************/
    if (outrootPrint == 1)
    {
        outroot = fopen("outroot.txt","w");
        if (nslay == 4) {
          fprintf(outroot,"%6s%6s%8s%10s%8s%8s\n",
              "year","day","Root1","Root2","Root3","Root4");
          for (i=day0 ; i<dayn ; i++)
            {
              fprintf(outroot,"%6d%6d%9.2lf%9.2lf%9.2lf%9.2lf\n",
                  meteo->year[i],meteo->yday[i],
                  soil->root[0][i],soil->root[1][i],soil->root[2][i],soil->root[3][i]);
            }
        }
        if (nslay == 5) {
          fprintf(outroot,"%6s%6s%8s%10s%8s%8s%8s\n",
              "year","day","Root1","Root2","Root3","Root4","Root5");
          for (i=day0 ; i<dayn ; i++)
            {
              fprintf(outroot,"%6d%6d%9.2lf%9.2lf%9.2lf%9.2lf%9.2lf\n",
                  meteo->year[i],meteo->yday[i],
                  soil->root[0][i],soil->root[1][i],soil->root[2][i],soil->root[3][i],soil->root[4][i]);
            }
        }
        //meteo->s_CO2[i]); // PAD 301008
        fclose(outroot);
    }

	/*****************************************/
	/* Soil Moisture outputs file PAD 131108 */
	/*****************************************/
    if (outsoilPrint == 1)
    {
        outsoil = fopen( "outsoil.txt", "w" );
        if (nslay == 4) {
          fprintf(outsoil," year  day  sm[1]   sm[2]   sm[3]   sm[4]  swp[1]   swp[2]   swp[3]   soilmm   soilice\n");
          for (i=day0 ; i<dayn ; i++)
            {
              fprintf(outsoil,"%6d%6d%12.4lf%12.4lf%12.4lf%12.4lf%26.4lf%26.4lf%26.4lf%26.4lf%26.4lf\n",
                  meteo->year[i],meteo->yday[i],
                  water->sm[0][i],water->sm[1][i],water->sm[2][i],water->sm[3][i],
                  water->swp[0][i],water->swp[1][i],water->swp[2][i],water->soil_mm[i],water->ice_mm[i]);
            }
        }
        if (nslay == 5) {
            fprintf(outsoil," year  day  sm[1]   sm[2]   sm[3]   sm[4]  sm[5]  swp[1]   swp[2]   swp[3]   swp[4]   soilmm   soilice\n");
            for (i=day0 ; i<dayn ; i++)
            {
                fprintf(outsoil,"%6d%6d%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%26.4lf%26.4lf%26.4lf%26.4lf%26.4lf%26.4lf\n",
                    meteo->year[i],meteo->yday[i],
                    water->sm[0][i],water->sm[1][i],water->sm[2][i],water->sm[3][i],water->sm[4][i],
                    water->swp[0][i],water->swp[1][i],water->swp[2][i],water->swp[3][i],
                    water->soil_mm[i],water->ice_mm[i]);
            }
        }
        fclose(outsoil);
    }

	/*****************************************/
	/* Snow and soil ice outputs file PAD 131108 */
	/*****************************************/
    if (outsnowPrint == 1)
    {
        outsnow = fopen( "outsnow.txt", "w" );
        if (nslay == 4) {
            fprintf(outsnow,"  year   day   dzsnow(m) h2osnow(kg) icesnow(kg) density(kg/m)  si[1](%%)    si[2](%%)    si[3](%%)    si[4](%%)\n");
            for (i=day0 ; i<dayn ; i++)
            {
                fprintf(outsnow,"%6d%6d%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf\n",
                    meteo->year[i],meteo->yday[i],
                    water->dzsnow[i],water->h2osnow[i],water->icesnow[i],water->icesnow[i]/water->dzsnow[i],
                    water->si[0][i],water->si[1][i],water->si[2][i],water->si[3][i]);
            }
        }
        fclose(outsnow);
    }
	/*****************************************/
	/* Temperature outputs file PAD 131108 */
	/*****************************************/
    if (outtempPrint == 1)
    {
        outtemp = fopen( "outtemp.txt", "w" );
        if (nslay == 4) {
            fprintf(outtemp,"  year   day        Tatm       Tsnow          T1          T2          T3          T4\n");
            for (i=day0 ; i<dayn ; i++)
            {
                fprintf(outtemp,"%6d%6d%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf\n",
                    meteo->year[i],meteo->yday[i],
                    meteo->s_tavg[i],soil->temp[0][i],
                    soil->temp[1][i],soil->temp[2][i],soil->temp[3][i],soil->temp[4][i]);
            }
        }
        fclose(outtemp);
    }

	/*****************************************/
	/* Soil evaporation */
	/*****************************************/
    if (outsoilevPrint == 1)
    {
        outsoilev = fopen("outsoilev.txt","w");
        fprintf(outsoilev," year day Se Ss time Epot aird satmrl soilrhl arh rsoil ra\n");
        for (i=day0 ; i<dayn ; i++)
        {
            fprintf(outsoilev,"%6d%6d%36.8lf%36.8lf%36.8lf%36.4lf%36.4lf%36.4lf%36.4lf%36.4lf%36.4lf%36.4lf\n",
                meteo->year[i],meteo->yday[i],water->se[i],water->ss[i],meteo->s_dayl[i],
                water->Epot_se[i],soilev->aird[i],soilev->satmrl[i],
                soilev->soilrhl[i],meteo->rh[i],soilev->rsoil[i],
                soilev->ra[i]);
        }
        fclose(outsoilev);
    }

	/*****************************************/
	/* Soil water */
	/*****************************************/
    if (outwaterPrint == 1)
    {
        outwater = fopen( "outwater.txt", "w" );
        fprintf(outwater," year day prcp pdirect through intercept canopy_snow se ss inf srun ct ddr soil_water Epot_through Epot_through_snow Epot_se lai wstress vpdstress photostress soil_rh r_soil sat_mr airrh s_swe\n");
        for (i=day0 ; i<dayn ; i++)
        {
            fprintf(outwater,"%6d%6d%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%14.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf %12.4lf %12.4lf %12.4lf%12.4lf%12.4lf%12.4lf\n",
                meteo->year[i],meteo->yday[i],
                meteo->s_prcp[i]+meteo->s_prcp_snow[i],water->pdirect[i]+water->psnowdirect[i],water->through[i]+water->through_snow[i],water->intercept[i],water->canopy_snow[i],
                water->se[i],water->ss[i],
                water->inf[i],water->srun[i],water->ct[i],water->ddr[i],water->soil_mm[i],
                water->Epot_through[i],water->Epot_through_snow[i],water->Epot_se[i],alloc->LAI[i],water->stress[i],photo->vpd_stress[i],photo->rh[i],
                water->soil_rh[i],water->r_soil[i],water->sat_mr[i],meteo->rh[i],meteo->s_swe[i]);
        }
        fclose(outwater);
    }

    if (outphenolPrint == 1)
    {
        outphenol = fopen( "outphenol.txt", "w" );
        fprintf(outphenol," year day veg_phase sumdd thawed\n");
        for (i=day0 ; i<dayn ; i++)
          {
            fprintf(outphenol,"%6d%6d%6d%12.4lf%6d\n",
                meteo->year[i],meteo->yday[i],
                phenol->veg_phase[i],phenol->sumdd[i],water->thawed[i]);
        }
        fclose(outphenol);
    }

    if (outradPrint == 1)
    {
        outrad = fopen("outrad.txt","w");
        fprintf(outrad," year day fpar lai laisun laishade par partop parabs parabs_sun parabs_shade parabs_psun parabs_pshade ppfd_sun ppfd_shade\n");
        for (i=day0 ; i<dayn ; i++)
        {
            fprintf(outrad,"%6d%6d%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf\n",
                meteo->year[i],meteo->yday[i],rad->f_par_srad[i],
                alloc->LAI[i],rad->plaisun[i],rad->plaishade[i],
                meteo->s_par[i],rad->par_top[i],rad->parabs[i],
                rad->parabs_plaisun[i],rad->parabs_plaishade[i],
                rad->parabs_per_plaisun[i],rad->parabs_per_plaishade[i],
                rad->ppfd_per_plaisun[i],rad->ppfd_per_plaishade[i]);
        }
        fclose(outrad);
    }

    if (outphotoPrint == 1)
    {
        outphoto = fopen( "outphoto.txt", "w" );
        fprintf(outphoto," year day laisun laishade Anet Acanopy Asuncanopy Ashadecanopy Asun Ashade Ajsun Ajshade Avsun Avshade Rday gssun gsshade cssun csshade cisun cishade Rdsun Rdshade vmax km gamma kc ko o2 jsun jshade photostress wstress vpdstress\n");
        for (i=day0 ; i<dayn ; i++)
        {
            fprintf(outphoto,"%6d%6d%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%18.4lf%18.4lf%18.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf\n",
                meteo->year[i],meteo->yday[i],rad->plaisun[i],rad->plaishade[i],alloc->A_net[i],
                photo->A_canopy[i],photo->A_sun_canopy[i],photo->A_shade_canopy[i],
                photo->A_sun[i],photo->A_shade[i],photo->Aj_sun[i],photo->Aj_shade[i],photo->Av_sun[i],photo->Av_shade[i],photo->Rday[i],
                photo->gs_c_sun[i],photo->gs_c_shade[i],photo->Cs_sun[i],photo->Cs_shade[i],photo->Ci_sun[i],photo->Ci_shade[i],photo->Rd_sun[i],photo->Rd_shade[i],
                photo->Vmax[i],photo->Km[i],photo->gamma[i],photo->Kc[i],photo->Ko[i],photo->O2[i],
                photo->J_sun[i],photo->J_shade[i],photo->rh[i],water->stress[i],photo->vpd_stress[i]);
        }
        fclose(outphoto);
    }

    if (outwatbalancePrint == 1)
    {
        outwatbalance = fopen( "outwatbalance.txt", "w" );
        z = par->year0_sim;
        fprintf(outwatbalance," year ct ddr se trough prcp srun intercept inf delta.sm init.sm fin.sm w_balance\n");
        for (y=(par->year0_sim-year0) ; y<(par->yearn_sim-year0+1) ; y++)
        {
            water_an->w_balance[y] = water_an->prcp[y] - water_an->ct[y] - water_an->ddr[y] - water_an->se[y] - water_an->intercept[y] - water_an->delta_sm[y];

            fprintf(outwatbalance,"%6d%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf\n",
                z,water_an->ct[y],water_an->ddr[y],water_an->se[y],water_an->through[y],
                water_an->prcp[y],water_an->srun[y],water_an->intercept[y],water_an->inf[y],
                water_an->delta_sm[y],water_an->sm_initial[y],water_an->sm_final[y],
                water_an->w_balance[y]);

            z = z + 1;
        }
        fclose(outwatbalance);
    }

    if (outalloc_yearPrint == 1)
    {
        outalloc_year = fopen( "outalloc_y.txt", "w" );
        z = par->year0_sim;
        fprintf(outalloc_year," year day12 day23 day23_sp day3spr3sum day34 day41 GPP NPP auto_resp LAIyear Dstem leaf root stem stor in_leaf out_leaf in_root out_root in_stem out_stem in_stor out_stor stor_leaf stor_root stor_stem npp_stor c_balance glumin Cmax2 T_previous_Y Pspring\n");
        for (y=(par->year0_sim-year0) ; y<(par->yearn_sim-year0+1) ; y++)
        {
            alloc->c_balance[y] = alloc->NPP[y] + alloc->outC_stor_y[y] - alloc->inC_leaf_y[y] - alloc->inC_root_y[y] - alloc->inC_stem_y[y] - alloc->inC_stor_y[y];

            fprintf(outalloc_year,"%6d%6d%12.4lf%12.4lf%6d%6d%6d%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf\n",
                z,phenol->day12[y],phenol->day23[y],phenol->day23_sp[y],alloc->day3spr3sum[y],phenol->day34[y],phenol->day41[y],alloc->GPP[y],alloc->NPP[y],alloc->auto_resp_y[y],alloc->LAI_year[y],
                alloc->stemi[y],alloc->C_leaf_year[y],alloc->C_root_year[y],alloc->C_stem_year[y],alloc->C_stor_year[y],
                alloc->inC_leaf_y[y],alloc->outC_leaf_y[y],
                alloc->inC_root_y[y],alloc->outC_root_y[y],
                alloc->inC_stem_y[y],alloc->outC_stem_y[y],
                alloc->inC_stor_y[y],alloc->outC_stor_y[y],
                alloc->stor_leaf[y],
                alloc->stor_root[y],
                alloc->stor_stem[y],
                alloc->npp_stor[y],
                alloc->c_balance[y],
                alloc->glumin[y],
                alloc->Cmax2[y],
                meteo->T_previous_Y[y],
                meteo->Pspring[y]);

            z = z + 1;
        }
        fclose(outalloc_year);
    }

    if (outalloc_dayPrint == 1)
    {
        outalloc_day = fopen( "outalloc_d.txt", "w" );
        fprintf(outalloc_day,	" year day period Acanopy AutoR Anet Cleaf Croot Cstem Cstor in_leaf in_root in_stem in_stor out_leaf out_root out_stem out_stor d_leaf d_root d_stem d_stor lai glumax\n");
        for (i=day0 ; i<dayn ; i++)
        {
            fprintf(outalloc_day,	"%6d%6d%6d%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf%12.4lf\n",
                meteo->year[i], meteo->yday[i], alloc->period[i],
                photo->A_canopy[i], alloc->auto_resp[i], alloc->A_net[i],
                alloc->C_leaf[i], alloc->C_root[i], alloc->C_stem[i], alloc->C_stor[i],
                alloc->inC_leaf[i], alloc->inC_root[i], alloc->inC_stem[i],
                alloc->inC_stor[i], alloc->outC_leaf[i], alloc->outC_root[i],
                alloc->outC_stem[i], alloc->outC_stor[i],
                alloc->dC_leaf[i],alloc->dC_root[i],alloc->dC_stem[i],alloc->dC_stor[i],
                alloc->LAI[i],
                alloc->glumax[i]);
        }
        fclose(outalloc_day);
    }

	// outsim version 4.1
    if (outsimPrint == 1)
    {
        outsim = fopen("outsim.txt","w");
        // Outsim version 4.2 to allow summer wood comparison PAD 280509
        var_mean=0.;
        Ny=0.;
        //printf("%i %i\n",year0_sim,year0);
        for (y=(par->year0_sim-year0) ; y<(par->yearn_sim-year0+1) ; y++)
        {
            day0 = 365 * y;
            dayn = day0 + 365;
            Ny = Ny + 1.;
            //printf("%i %i %12.4lf %12.4lf\n",day0,dayn,Ny,var_mean);
            for (i=day0 ; i<dayn ; i++)
            {
                if (alloc->outC_stor[i] == 0. and alloc->inC_stem[i] >=0.)
                { var_mean = var_mean+alloc->inC_stem[i]; }
            }
        }
        var_mean=var_mean/Ny ;
        //printf("%.f %.f %i %i\n",var_mean,Ny,nyear_sim,yearn_sim);

        fprintf(outsim," simul\n");
        for (y=(par->year0_sim-year0) ; y<(par->yearn_sim-year0+1) ; y++)
        {
            day0 = 365 * y;
            dayn = day0 + 365;

            var_sim=0. ;
            for (i=day0 ; i<dayn ; i++)
            {
                if (alloc->outC_stor[i] == 0. and alloc->inC_stem[i] >=0.)
                { var_sim=var_sim+alloc->inC_stem[i]; }
            }
            //printf("%i %.lf %.lf\n",y,var_sim,var_mean);
            var_sim = var_sim-var_mean;
            //printf("%i %12.4lf\n",y,var_sim);
            fprintf(outsim,"%12.4lf\n",var_sim);
        }
        fclose(outsim);
    }

    if (outcustomPrint == 1) //Change this for your own convenience
    {
        outcustom = fopen("outcustom.txt","w");
        fprintf(outcustom,"%4s%8s%12s%12s%12s%12s%12s%12s%12s%12s%12s%12s%12s%12s%12s%12s\n",
                "year","day","Tmax","Tmin","Tavg","Tday","rain","snow","CO2","d18Oprcp","d18OTRC","d13CTRC","period","Cstem","inCstem","Acanopy");
        for (i=day0 ; i<dayn ; i++)
        {
            fprintf(outcustom,"%4d\t%4d\t%8.2lf\t%8.2lf\t%8.2lf\t%8.2lf\t%8.2lf\t%9.2lf\t%9.2lf\t%9.2lf\t%9.2lf\t%10.2lf\t%4d\t%10.2lf\t%10.2lf\t%10.2lf\n",
                    meteo->year[i],meteo->yday[i],meteo->s_tmax[i],meteo->s_tmin[i],meteo->s_tavg[i],meteo->s_tday[i],meteo->s_prcp[i],meteo->s_prcp_snow[i],meteo->s_CO2[i],d18O->through[i],d18O->TRC[i],d13C->DTRC[i],alloc->period[i],alloc->C_stem[i],alloc->inC_stem[i],photo->A_canopy[i]);
        }
        fclose(outcustom);
    }

	return (!ok);
}
/* end of write_out */

/*******************************************************************/
/* data_free frees the memory previously allocated by data_alloc() */
/*******************************************************************/
int data_free(meteo_struct *meteo,soil_struct *soil,water_struct *water,
	      radiation_struct *rad, photo_struct *photo,
	      allocation_struct *alloc, water_an_struct *water_an,
	      phenol_struct *phenol,
	      d18O_struct *d18O, d2H_struct *d2H, d13C_struct *d13C) // PAD 3110008
{
	int ok=1;

	free(meteo->year);
	free(meteo->yday);
	free(meteo->tmax);
	free(meteo->tmin);
	free(meteo->prcp);
	free(meteo->CO2); // PAD 291008
	free(d18O->precip); // PAD 131108
	free(d18O->vapor);  // PAD 131108
	free(d18O->Epot_through); // PAD 241108
	free(d18O->Epot_through_snow); // PAD 180719
	free(d18O->cws);    // PAD 241108
	free(d18O->css);    // PAD 180719
	free(d18O->through); // PAD 241108
	free(d18O->through_snow); // PAD 180719
	free(d18O->infl);    // PAD 131108
	free(d18O->xylem);   // PAD 131108
	free(d18O->TRC); // PAD 241108
	free(d18O->soilevap); // PAD 241108
	free(d18O->snowevap); // PAD 290819
	free(d2H->precip); // PAD 131108
	free(d2H->vapor); // PAD 131108
	free(d2H->Epot_through); // PAD 241108
	free(d2H->Epot_through_snow); // PAD 180719
	free(d2H->cws); // PAD 241108
	free(d2H->css);     // PAD 180719
	free(d2H->through); // PAD 241108
	free(d2H->through_snow); // PAD 180719
	free(d2H->infl); // PAD 131108
	///free(d2H->xylem); // PAD 131108 //FG_ERROR
	free(d2H->TRC); // PAD 241108
	free(d2H->soilevap); // PAD 241108
	free(d2H->snowevap); // PAD 290819
	free(d13C->DTRC); // PAD 220409
	free(d13C->TRCnew); // PAD 170909
	free(d13C->CCi_CO2); // PAD 180509
	free(d13C->d13CO2); // PAD 170909
	free(d13C->stor); // PAD 170909
	free(meteo->s_tmax);
	free(meteo->s_tmin);
	free(meteo->s_tday);
	free(meteo->s_tday_transf); //FG
	free(meteo->s_prcp);
	free(meteo->s_prcp_snow);
	free(meteo->s_hum);
	free(meteo->s_srad);
	free(meteo->s_dayl);
	free(meteo->s_par);
	free(meteo->s_swe);
	free(meteo->s_pa);
	free(meteo->s_avp);
	free(meteo->s_gbh);
	free(meteo->s_gbc);
	free(meteo->s_gaer);
	free(meteo->s_surft);
	free(meteo->s_CO2); // PAD 281008
	free(water->srun);
	free(water->ddr);
	free(water->through);
	free(water->through_snow);
	free(water->canopy_snow);
	free(water->se);
	free(water->ss);
	free(water->ct);
	free(water->trans_sun);
	free(water->trans_shade);
	free(water->Epot_through);
	free(water->Epot_through_snow);
	free(water->Epot_se);
	free(water->stress);
    free(water->thaw_flag);
    free(water->thawed);
	free(water->inf);
	free(soil->swp);
	free(photo->gb_c);
	free(alloc->A_net);
	free(photo->Aj_sun);
	free(photo->Av_sun);
	free(photo->A_sun);
	free(photo->Cs_sun);
	free(photo->gs_c_sun);
	free(photo->Ci_sun);
	free(photo->Aj_shade);
	free(photo->Av_shade);
	free(photo->A_shade);
	free(photo->Cs_shade);
	free(photo->gs_c_shade);
	free(photo->Ci_shade);
	free(photo->A_sun_canopy);
	free(photo->A_shade_canopy);
	free(photo->A_canopy);
	free(photo->Km);
	free(photo->Kc);
	free(photo->Ko);
	free(photo->O2);
	free(photo->Vmax);
	free(photo->gamma);
	free(photo->J_sun);
	free(photo->J_shade);
	free(photo->rh);
	free(water_an->ct);
	free(water_an->ddr);
	free(water_an->se);
	free(water_an->through);
	free(water_an->prcp);
	free(water_an->srun);
	free(water_an->delta_sm);
	free(water_an->sm_initial);
	free(water_an->sm_final);
	free(water_an->intercept);
	free(water_an->inf);
	free(alloc->inC_stor_y);

        printf("data_free() ok\n");

	return (!ok);
}
/* end of data_free */

